@@ -1092,7 +1092,7 @@ class Text_Wiki {
             }
         }
         
-        $this->parseObj[$rule] =& new $class($this);
+        $this->parseObj[$rule] = new $class($this);
 
     }
     
@@ -1126,7 +1126,7 @@ class Text_Wiki {
             }
         }
         
-        $this->renderObj[$rule] =& new $class($this);
+        $this->renderObj[$rule] = new $class($this);
     }
     
     
@@ -1157,7 +1157,7 @@ class Text_Wiki {
             }
         }
         
-        $this->formatObj[$format] =& new $class($this);
+        $this->formatObj[$format] = new $class($this);
     }
     
     
