@@ -1,4 +1,4 @@
-<?php # $Id: comments.inc.php 2362 2008-10-23 13:50:54Z garvinhicking $
+<?php # $Id: comments.inc.php 2606 2009-12-08 14:03:37Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -67,7 +67,7 @@ if (isset($serendipity['GET']['adminAction']) && $serendipity['GET']['adminActio
             FROM {$serendipity['dbPrefix']}comments c
             LEFT JOIN {$serendipity['dbPrefix']}entries e ON (e.id = c.entry_id)
             LEFT JOIN {$serendipity['dbPrefix']}authors a ON (e.authorid = a.authorid)
-            WHERE c.id = " . (int)$serendipity['GET']['id']  ." AND status = 'pending'";
+            WHERE c.id = " . (int)$serendipity['GET']['id']  ." AND (status = 'pending' OR status LIKE 'confirm%')";
     $rs  = serendipity_db_query($sql, true);
 
     if ($rs === false) {
@@ -201,6 +201,9 @@ if ($serendipity['GET']['filter']['show'] == 'approved') {
 } elseif ($serendipity['GET']['filter']['show'] == 'pending') {
     $and           .= "AND status = 'pending'";
     $searchString .= "&amp;serendipity[filter][show]=pending";
+} elseif ($serendipity['GET']['filter']['show'] == 'confirm') {
+    $and           .= "AND status LIKE 'confirm%'";
+    $searchString .= "&amp;serendipity[filter][show]=confirm";
 } else {
     $serendipity['GET']['filter']['show'] = 'all';
 }
@@ -284,14 +287,33 @@ function invertSelection() {
         }
     }
 }
+
+var origborder = '';
+var origwidth = '';
+
 function highlightComment(id, checkvalue) {
     var comment = document.getElementById(id);
+    
+    if (origborder == '') {
+        origborder = comment.style.borderColor;
+        if (origborder == '') {
+            origborder = '#FFFFFF';
+        }
+    }
+    
+    if (origwidth == '') {
+        origwidth = comment.style.borderWidth;
+        if (origwidth == '' || origwidth == 0) {
+            origwidth = 1;
+        }
+    }
+    
     if (checkvalue) {
         comment.style.borderColor = '#FF0000';
-        comment.style.borderWidth = 2;
+        comment.style.borderWidth = origwidth;
     } else {
         comment.style.borderColor = '';
-        comment.style.borderWidth = '';
+        comment.style.borderWidth = origwidth;
     }
 }
 </script>
@@ -335,6 +357,7 @@ function highlightComment(id, checkvalue) {
                 <option value="all"<?php if ( $serendipity['GET']['filter']['show'] == 'all' ) echo ' selected="selected"' ?>><?php echo COMMENTS_FILTER_ALL ?></option>
                 <option value="approved"<?php if ( $serendipity['GET']['filter']['show'] == 'approved' ) echo ' selected="selected"' ?>><?php echo COMMENTS_FILTER_APPROVED_ONLY ?></option>
                 <option value="pending"<?php if ( $serendipity['GET']['filter']['show'] == 'pending' ) echo ' selected="selected"' ?>><?php echo COMMENTS_FILTER_NEED_APPROVAL ?></option>
+                <option value="confirm"<?php if ( $serendipity['GET']['filter']['show'] == 'confirm' ) echo ' selected="selected"' ?>><?php echo COMMENTS_FILTER_NEED_CONFIRM ?></option>
             </select></td>
         <td><?php echo TYPE; ?></td>
         <td><select name="serendipity[filter][type]">
@@ -418,8 +441,14 @@ foreach ($sql as $rs) {
     $class = 'serendipity_admin_list_item_' . (($i % 2 == 0 ) ? 'even' : 'uneven');
     if ($comment['status'] == 'pending') {
         $class .= ' serendipity_admin_comment_pending'; 
+        $header_class = 'serendipityAdminMsgNote serendipity_admin_comment_pending_header';
+    } elseif (strstr($comment['status'], 'confirm')) {
+        $class .= ' serendipity_admin_comment_pending serendipity_admin_comment_confirm'; 
+        $header_class = 'serendipityAdminMsgNote serendipity_admin_comment_pending_header serendipity_admin_comment_confirm_header';
+    } else {
+        $header_class = '';
     }
-    $header_class = ($comment['status'] == 'pending' ? 'serendipityAdminMsgNote serendipity_admin_comment_pending_header' : '');
+
 
     if (!empty($comment['url']) && substr($comment['url'], 0, 7) != 'http://' &&
          substr($comment['url'], 0, 8) != 'https://') {
@@ -429,7 +458,7 @@ foreach ($sql as $rs) {
 ?>
 <tr>
     <td class="<?php echo $header_class; ?>">
-<?php   if ($header_class=='serendipityAdminMsgNote serendipity_admin_comment_pending_header') { ?>
+<?php   if (!empty($header_class)) { ?>
             <img style="width: 22px; height: 22px; border: 0px; padding-right: 4px; vertical-align: middle" src="<?php echo serendipity_getTemplateFile('admin/img/admin_msg_note.png'); ?>" alt="" />
 <?php   }?>
         <a name="c<?php echo $comment['id'] ?>"></a>
@@ -494,7 +523,7 @@ foreach ($sql as $rs) {
                 </td>
             </tr>
         </table>
-<?php if ($comment['status'] == 'pending') { ?>
+<?php if ($comment['status'] == 'pending' || strstr($comment['status'], 'confirm')) { ?>
           <a href="?serendipity[action]=admin&amp;serendipity[adminModule]=comments&amp;serendipity[adminAction]=approve&amp;serendipity[id]=<?php echo $comment['id'] ?>&amp;<?php echo serendipity_setFormToken('url'); ?>" class="serendipityIconLink" title="<?php echo APPROVE; ?>"><img src="<?php echo serendipity_getTemplateFile('admin/img/accept.png'); ?>" alt="<?php echo APPROVE ?>" /><?php echo APPROVE ?></a>
 <?php } ?>
 <?php if ($comment['status'] == 'approved') { ?>
@@ -518,5 +547,26 @@ foreach ($sql as $rs) {
     <td><input type="button" name="toggle" value="<?php echo INVERT_SELECTIONS ?>" onclick="invertSelection()" class="serendipityPrettyButton input_button" /> <input type="submit" name="toggle" value="<?php echo DELETE_SELECTED_COMMENTS ?>" onclick="return confirm('<?php echo COMMENTS_DELETE_CONFIRM ?>')" tabindex="<?php echo ($i+1) ?>" class="serendipityPrettyButton input_button" /></td>
 </tr>
 </table>
+<table width="100%" cellpadding="3" border="0" cellspacing="0">
+<tr>
+    <td align="center">
+        <table width="100%" cellspacing="5" cellpadding="0" border="0">
+            <tr>
+                <td>
+                <?php if ( $page != 1 && $page <= $pages ) { ?>
+                    <a href="<?php echo $linkPrevious; ?>" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/previous.png') ?>" /><?php echo PREVIOUS ?></a>
+                <?php } ?>
+                </td>
+                <td align="center"><?php printf(PAGE_BROWSE_COMMENTS, $page, $pages, $totalComments); ?></td>
+                <td align="right">
+                <?php if ( $page != $pages ) { ?>
+                    <a href="<?php echo $linkNext; ?>" class="serendipityIconLinkRight"><?php echo NEXT ?><img src="<?php echo serendipity_getTemplateFile('admin/img/next.png') ?>" /></a>
+                <?php } ?>
+                </td>
+            </tr>
+        </table>
+    </td>
+</tr>
+
 </form>
 <?php } ?>
