@@ -1,4 +1,4 @@
-<?php # $Id: entries.inc.php 2383 2008-11-25 19:57:49Z slothman $
+<?php # $Id: entries.inc.php 2546 2009-07-10 15:45:18Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -113,9 +113,10 @@ function serendipity_drawList() {
                 <select name="serendipity[filter][author]">
                     <option value="">--</option>
 <?php
-                    $users = serendipity_fetchUsers();
+                    $users = serendipity_fetchUsers('', null, true);
                     if (is_array($users)) {
                         foreach ($users AS $user) {
+                            if (isset($user['artcount']) && $user['artcount'] < 1) continue;
                             echo '<option value="' . $user['authorid'] . '" ' . (isset($serendipity['GET']['filter']['author']) && $serendipity['GET']['filter']['author'] == $user['authorid'] ? 'selected="selected"' : '') . '>' . htmlspecialchars($user['realname']) . '</option>' . "\n";
                         }
                     }
