@@ -1,4 +1,4 @@
-<?php # $Id: installer.inc.php 2328 2008-08-29 07:54:02Z garvinhicking $
+<?php # $Id: installer.inc.php 2544 2009-07-10 13:50:13Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -363,7 +363,7 @@ if ( (int)$serendipity['GET']['step'] == 0 ) {
         <td colspan="2" style="font-weight: bold"><?php echo PERMISSIONS ?></td>
     </tr>
     <tr>
-        <td><?php echo $basedir ?></td>
+        <td style="vertical-align: top"><?php echo $basedir ?></td>
         <td width="200"><?php
             $basewritable = False;
             if ( is_writable($basedir) ) {
@@ -385,6 +385,7 @@ if ( (int)$serendipity['GET']['step'] == 0 ) {
                         break;
                     }
                 }
+                
                 if (!$showWritableNote) {
                     echo serendipity_installerResultDiagnose(S9Y_I_SUCCESS, WRITABLE);
                 }
@@ -392,7 +393,7 @@ if ( (int)$serendipity['GET']['step'] == 0 ) {
      ?></td>
     </tr>
     <tr>
-        <td><?php echo $basedir . PATH_SMARTY_COMPILE?></td>
+        <td style="vertical-align: top"><?php echo $basedir . PATH_SMARTY_COMPILE?></td>
         <td width="200"><?php
             if ( is_writable($basedir . PATH_SMARTY_COMPILE) ) {
                 echo serendipity_installerResultDiagnose(S9Y_I_SUCCESS, WRITABLE);
@@ -408,7 +409,7 @@ if ( (int)$serendipity['GET']['step'] == 0 ) {
      ?></td>
     </tr>
     <tr>
-        <td><?php echo $basedir . 'archives/'?></td>
+        <td style="vertical-align: top"><?php echo $basedir . 'archives/'?></td>
         <td width="200"><?php
             if ( is_writable($basedir . 'archives/') ) {
                 echo serendipity_installerResultDiagnose(S9Y_I_SUCCESS, WRITABLE);
@@ -423,9 +424,20 @@ if ( (int)$serendipity['GET']['step'] == 0 ) {
             }
      ?></td>
     </tr>
+    <tr>
+        <td style="vertical-align: top"><?php echo $basedir . 'plugins/'?></td>
+        <td width="200"><?php
+            if ( is_writable($basedir . 'plugins/') ) {
+                echo serendipity_installerResultDiagnose(S9Y_I_SUCCESS, WRITABLE);
+            } else {
+                echo serendipity_installerResultDiagnose(S9Y_I_WARNING, NOT_WRITABLE . NOT_WRITABLE_SPARTACUS);
+            }
+     ?></td>
+    </tr>
+
 <?php if ( is_dir($basedir .'uploads/') ) { ?>
     <tr>
-        <td><?php echo $basedir . 'uploads/'?></td>
+        <td style="vertical-align: top"><?php echo $basedir . 'uploads/'?></td>
         <td width="200"><?php
             if ( is_writable($basedir . 'uploads/') ) {
                 echo serendipity_installerResultDiagnose(S9Y_I_SUCCESS, WRITABLE);
@@ -443,7 +455,7 @@ if ( (int)$serendipity['GET']['step'] == 0 ) {
 <?php } ?>
 <?php if (function_exists('is_executable')) { ?>
     <tr>
-      <td>Execute Imagemagick  binary </td>
+      <td style="vertical-align: top">Execute Imagemagick  binary </td>
       <td><?php
             if ($binary = serendipity_query_default('convert', false)) {
                 if (is_executable($binary)) {
@@ -516,7 +528,7 @@ if ( (int)$serendipity['GET']['step'] == 0 ) {
         echo ' <strong>' . DONE . '</strong><br />';
 
         echo sprintf(CREATING_PRIMARY_AUTHOR, htmlspecialchars($_POST['user'])) .'...';
-        $authorid = serendipity_addAuthor($_POST['user'], $_POST['pass'], $_POST['realname'], $_POST['email'], USERLEVEL_ADMIN);
+        $authorid = serendipity_addAuthor($_POST['user'], $_POST['pass'], $_POST['realname'], $_POST['email'], USERLEVEL_ADMIN, 1);
         $mail_comments =  (serendipity_db_bool($_POST['want_mail']) ? 1 : 0);
         serendipity_set_user_var('mail_comments', $mail_comments, $authorid);
         serendipity_set_user_var('mail_trackbacks', $mail_comments, $authorid);
