@@ -1,4 +1,4 @@
-<?php # $Id: upgrader.inc.php 1815 2007-08-06 10:18:26Z garvinhicking $
+<?php # $Id: upgrader.inc.php 2397 2008-12-09 10:41:48Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -28,16 +28,16 @@ function serendipity_upgraderResultDiagnose($result, $s) {
     global $errorCount;
 
     if ( $result === S9Y_U_SUCCESS ) {
-        return '<span style="color: green; font-weight: bold">'. $s .'</span>';
+        return '<span class="serendipityAdminMsgSuccessInstall" style="color: green; font-weight: bold">'. $s .'</span>';
     }
 
     if ( $result === S9Y_U_WARNING ) {
-        return '<span style="color: orange; font-weight: bold">'. $s .'</span>';
+        return '<span class="serendipityAdminMsgWarningInstall" style="color: orange; font-weight: bold">'. $s .'</span>';
     }
 
     if ( $result === S9Y_U_ERROR ) {
         $errorCount++;
-        return '<span style="color: red; font-weight: bold">'. $s .'</span>';
+        return '<span class="serendipityAdminMsgErrorInstall" style="color: red; font-weight: bold">'. $s .'</span>';
     }
 }
 
@@ -264,6 +264,25 @@ if (($showAbort && $serendipity['GET']['action'] == 'ignore') || $serendipity['G
 ?>
 <div align="center">
 <table class="serendipity_admin_list_item serendipity_admin_list_item_even" width="90%" align="center">
+<?php if (is_readable($basedir . 'checksums.inc.php')) {
+    $badsums = serendipity_verifyFTPChecksums();
+?>
+    <tr>
+        <td colspan="2" style="font-weight: bold"><?php echo INTEGRITY ?></td>
+    </tr>
+    <tr>
+        <td width="200"><?php
+            if ( empty($badsums) ) {
+                echo serendipity_upgraderResultDiagnose(S9Y_U_SUCCESS, CHECKSUMS_PASS);
+            } else {
+                foreach ($badsums as $rfile => $sum) {
+                    echo serendipity_upgraderResultDiagnose(S9Y_U_WARNING, sprintf(CHECKSUM_FAILED, $rfile)) . "<br />\n";
+                }
+            }
+     ?></td>
+    </tr>
+<?php } // End if checksums
+?>
     <tr>
         <td colspan="2" style="font-weight: bold"><?php echo PERMISSIONS ?></td>
     </tr>
