@@ -95,7 +95,7 @@ function serendipity_db_limit($start, $offset) {
  * @return  SQL string containing a full LIMIT statement
  */
 function serendipity_db_limit_sql($limitstring) {
-    $limit_split = split(',', $limitstring);
+    $limit_split = explode(',', $limitstring);
     if (count($limit_split) > 1) {
         $limit = ' LIMIT ' . $limit_split[0] . ' OFFSET ' . $limit_split[1];
     } else {
@@ -187,7 +187,7 @@ function serendipity_db_insert_id($table = '', $id = '') {
  */
 function &serendipity_db_query($sql, $single = false, $result_type = "both", $reportErr = false, $assocKey = false, $assocVal = false, $expectError = false) {
     global $serendipity;
-    static $type_map = array(
+    $type_map = array(
                          'assoc' => PDO::FETCH_ASSOC,
                          'num'   => PDO::FETCH_NUM,
                          'both'  => PDO::FETCH_BOTH,
