@@ -1,4 +1,4 @@
-<?php # $Id: sqlite.inc.php 2327 2008-08-29 07:10:31Z garvinhicking $
+<?php # $Id: sqlite.inc.php 2559 2009-07-27 09:52:13Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -212,7 +212,7 @@ function serendipity_db_in_sql($col, &$search_ids, $type = ' OR ') {
 function &serendipity_db_query($sql, $single = false, $result_type = "both", $reportErr = true, $assocKey = false, $assocVal = false, $expectError = false)
 {
     global $serendipity;
-    static $type_map = array(
+    $type_map = array(
                          'assoc' => SQLITE_ASSOC,
                          'num'   => SQLITE_NUM,
                          'both'  => SQLITE_BOTH,
