@@ -115,7 +115,7 @@ function generate_resultset($cursor, $result_type = 'sqlr_BOTH') {
 
 function &serendipity_db_query($sql, $single = false, $result_type = "both", $reportErr = false, $assocKey = false, $assocVal = false, $expectError = false) {
     global $serendipity;
-    static $type_map = array(
+    $type_map = array(
                          'assoc' => sqlr_ASSOC,
                          'num'   => sqlr_NUM,
                          'both'  => sqlr_BOTH,
@@ -388,7 +388,7 @@ function serendipity_db_limit_sql($limitstring) {
        return ' LIMIT ' . $limitstring;
     case "postgresql":
         $limit;
-        $limit_split = split(',', $limitstring);
+        $limit_split = explode(',', $limitstring);
         if (count($limit_split) > 1) {
             $limit = ' LIMIT ' . $limit_split[0] . ' OFFSET ' . $limit_split[1];
         } else {
