@@ -1,4 +1,4 @@
-<?php # $Id: functions.inc.php 2363 2008-10-28 12:32:30Z garvinhicking $
+<?php # $Id: functions.inc.php 2585 2009-09-21 08:11:35Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -222,7 +222,7 @@ function serendipity_fetchTemplates($dir = '') {
         return $rv;
     }
     while (($file = readdir($cdir)) !== false) {
-        if (is_dir($serendipity['serendipityPath'] . $serendipity['templatePath'] . $dir . $file) && !ereg('^(\.|CVS)', $file) && !file_exists($serendipity['serendipityPath'] . $serendipity['templatePath'] . $dir . $file . '/inactive.txt')) {
+        if (is_dir($serendipity['serendipityPath'] . $serendipity['templatePath'] . $dir . $file) && !preg_match('@^(\.|CVS)@i', $file) && !file_exists($serendipity['serendipityPath'] . $serendipity['templatePath'] . $dir . $file . '/inactive.txt')) {
             if (file_exists($serendipity['serendipityPath'] . $serendipity['templatePath'] . $dir . $file . '/info.txt')) {
                 $key = strtolower($file);
                 if (isset($rv[$key])) {
@@ -377,7 +377,7 @@ function serendipity_fetchUsers($user = '', $group = null, $is_count = false) {
         if ($serendipity['dbType'] == 'postgres' ||
             $serendipity['dbType'] == 'pdo-postgres') {
             // Why does PostgreSQL keep doing this to us? :-)
-            $query_group    = 'GROUP BY a.authorid, a.realname, a.username, a.password, a.mail_comments, a.mail_trackbacks, a.email, a.userlevel, a.right_publish';
+            $query_group    = 'GROUP BY a.authorid, a.realname, a.username, a.password, a.hashtype, a.mail_comments, a.mail_trackbacks, a.email, a.userlevel, a.right_publish';
             $query_distinct = 'DISTINCT';
         } else {
             $query_group    = 'GROUP BY a.authorid';
@@ -392,6 +392,7 @@ function serendipity_fetchUsers($user = '', $group = null, $is_count = false) {
                                a.realname,
                                a.username,
                                a.password,
+                               a.hashtype,
                                a.mail_comments,
                                a.mail_trackbacks,
                                a.email,
@@ -418,6 +419,7 @@ function serendipity_fetchUsers($user = '', $group = null, $is_count = false) {
                                a.realname,
                                a.username,
                                a.password,
+                               a.hashtype,
                                a.mail_comments,
                                a.mail_trackbacks,
                                a.email,
@@ -539,7 +541,7 @@ function serendipity_sendMail($to, $subject, $message, $fromMail, $headers = NUL
         fclose($fp);
     }
 
-    if (!isset($maildata['skip_native'])) {
+    if (!isset($maildata['skip_native']) && !empty($maildata['to'])) {
         return mail($maildata['to'], $maildata['subject'], $maildata['message'], implode("\n", $maildata['headers']));
     }
 }
