@@ -1,4 +1,4 @@
-<?php # $Id: functions_comments.inc.php 2376 2008-11-14 10:06:54Z garvinhicking $
+<?php # $Id: functions_comments.inc.php 2539 2009-07-04 01:37:47Z brockhaus $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -369,6 +369,11 @@ function serendipity_printComments($comments, $parentid = 0, $depth = 0, $trace
             $comment['url']     = strip_tags($comment['url']);
             $comment['link_delete'] = $serendipity['baseURL'] . 'comment.php?serendipity[delete]=' . $comment['id'] . '&amp;serendipity[entry]=' . $comment['entry_id'] . '&amp;serendipity[type]=comments';
 
+            /* Fix invalid cases in protocoll part */
+            if (!empty($comment['url'])) {
+                $comment['url'] = preg_replace('@^http://@i','http://', $comment['url']);
+                $comment['url'] = preg_replace('@^https://@i','https://', $comment['url']);
+            }
             /* Fix fucked links */
             if (!empty($comment['url']) && substr($comment['url'], 0, 7) != 'http://' && substr($comment['url'], 0, 8) != 'https://') {
                 $comment['url'] = 'http://' . $comment['url'];
@@ -658,7 +663,7 @@ function serendipity_approveComment($cid, $entry_id, $force = false, $moderate =
     $counter_tb = serendipity_db_query("SELECT count(id) AS counter 
                                           FROM {$serendipity['dbPrefix']}comments 
                                          WHERE status = 'approved' 
-                                           AND type   = 'TRACKBACK'
+                                           AND (type = 'TRACKBACK' or type = 'PINGBACK')
                                            AND entry_id = " . (int)$entry_id . "
                                       GROUP BY entry_id", true);
 
@@ -893,6 +898,8 @@ function serendipity_insertComment($id, $commentInfo, $type = 'NORMAL', $source
     if ($GLOBALS['tb_logging']) {
         fclose($fp);
     }
+    
+    return $cid;
 }
 
 /**
@@ -958,7 +965,7 @@ function serendipity_saveComment($id, $commentInfo, $type = 'NORMAL', $source =
             fclose($fp);
         }
                         
-        serendipity_insertComment($id, $commentInfo, $type, $source, $ca);
+        $commentInfo['comment_cid'] = serendipity_insertComment($id, $commentInfo, $type, $source, $ca);
         $commentInfo['comment_id'] = $id;
         serendipity_plugin_api::hook_event('frontend_saveComment_finish', $ca, $commentInfo);
         return true;
