@@ -1,4 +1,4 @@
-<?php # $Id: functions_config.inc.php 2409 2008-12-20 17:51:46Z garvinhicking $
+<?php # $Id: functions_config.inc.php 2598 2009-11-28 12:27:42Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -22,15 +22,17 @@ if (defined('S9Y_FRAMEWORK_CONFIG')) {
  * @param   int     The userlevel of a user
  * @return  int     The new user ID of the added author
  */
-function serendipity_addAuthor($username, $password, $realname, $email, $userlevel=0) {
+function serendipity_addAuthor($username, $password, $realname, $email, $userlevel=0, $hashtype=1) {
     global $serendipity;
-    $password = md5($password);
-    $query = "INSERT INTO {$serendipity['dbPrefix']}authors (username, password, realname, email, userlevel)
+    $password = serendipity_hash($password);
+    $query = "INSERT INTO {$serendipity['dbPrefix']}authors (username, password, realname, email, userlevel, hashtype)
                         VALUES  ('" . serendipity_db_escape_string($username) . "',
                                  '" . serendipity_db_escape_String($password) . "',
                                  '" . serendipity_db_escape_String($realname) . "',
                                  '" . serendipity_db_escape_String($email) . "',
-                                 '" . serendipity_db_escape_String($userlevel) . "')";
+                                 '" . serendipity_db_escape_String($userlevel) . "',
+                                 '" . serendipity_db_escape_String($hashtype) . "'
+                                 )";
     serendipity_db_query($query);
     $cid = serendipity_db_insert_id('authors', 'authorid');
 
@@ -224,7 +226,7 @@ function serendipity_set_user_var($name, $val, $authorid, $copy_to_s9y = true) {
                 return;
             }
 
-            $val = md5($val);
+            $val = serendipity_hash($val);
             $copy_to_s9y = false;
             break;
 
@@ -492,60 +494,120 @@ function serendipity_setAuthorToken() {
  * @param   boolean     Indicates whether to query external plugins for authentication
  * @return  boolean     True on success, False on error
  */
-function serendipity_authenticate_author($username = '', $password = '', $is_md5 = false, $use_external = true) {
+function serendipity_authenticate_author($username = '', $password = '', $is_hashed = false, $use_external = true) {
     global $serendipity;
+    static $debug = false;
+    static $debugc = 0;
+    
+    if ($debug) {
+        $fp = fopen('login.log', 'a');
+        flock($fp, LOCK_EX);
+        $debugc++;
+        fwrite($fp, date('Y-m-d H:i') . ' - #' . $debugc . ' Login init [' . $username . ',' . $password . ',' . (int)$is_hashed . ',' . (int)$use_external . ']' . ' (' . $_SERVER['REMOTE_ADDR'] . ',' . $_SERVER['REQUEST_URI'] . ', ' . session_id() . ')' . "\n");
+    }
 
     if (isset($_SESSION['serendipityUser']) && isset($_SESSION['serendipityPassword']) && isset($_SESSION['serendipityAuthedUser']) && $_SESSION['serendipityAuthedUser'] == true) {
         $username = $_SESSION['serendipityUser'];
         $password = $_SESSION['serendipityPassword'];
         // For safety reasons when multiple blogs are installed on the same host, we need to check the current author each time to not let him log into a different blog with the same sessiondata
-        $is_md5 = true;
+        #$is_hashed = true;
+        if ($debug) fwrite($fp, date('Y-m-d H:i') . ' - Recall from session: ' . $username . ':' . $password . "\n");
     }
 
+    if ($debug) fwrite($fp, date('Y-m-d H:i') . ' - Login ext check' . "\n");
     $is_authenticated = false;
     serendipity_plugin_api::hook_event('backend_login', $is_authenticated, NULL);
     if ($is_authenticated) {
         return true;
     }
 
+    if ($debug) fwrite($fp, date('Y-m-d H:i') . ' - Login username check:' . $username . "\n");
     if ($username != '') {
         if ($use_external) {
-            serendipity_plugin_api::hook_event('backend_auth', $is_md5, array('username' => $username, 'password' => $password));
-        }
-
-        if ($is_md5 === false && !empty($password)) {
-            $password = md5($password);
+            serendipity_plugin_api::hook_event('backend_auth', $is_hashed, array('username' => $username, 'password' => $password));
         }
 
         $query = "SELECT DISTINCT
-                    email, realname, authorid, userlevel, right_publish
+                    email, password, realname, authorid, userlevel, right_publish, hashtype
                   FROM
                     {$serendipity['dbPrefix']}authors
                   WHERE
-                    username   = '" . serendipity_db_escape_string($username) . "'
-                  AND password = '" . serendipity_db_escape_string($password) . "'";
-        $row =& serendipity_db_query($query, true, 'assoc');
+                    username   = '" . serendipity_db_escape_string($username) . "'";
+        if ($debug) fwrite($fp, date('Y-m-d H:i') . ' - Login check (' . serialize($is_hashed) . ', ' . $_SESSION['serendipityPassword'] . '):' . $query . "\n");
 
-        if (is_array($row)) {
-            serendipity_setCookie('old_session', session_id(), false);
-            if (!$is_md5) {
-                serendipity_setAuthorToken();
+        $rows =& serendipity_db_query($query, false, 'assoc');
+        if (is_array($rows)) {
+            foreach($rows AS $row) {
+                if ($is_valid_user) continue;
+                $is_valid_user = false;
+
+                // Old MD5 hashing routine. Will convert user.
+                if (empty($row['hashtype']) || $row['hashtype'] == 0) {
+                    
+                    if (isset($serendipity['hashkey']) && (time() - $serendipity['hashkey']) >= 15768000) {
+                        die('You can no longer login with an old-style MD5 hash to prevent MD5-Hostage abuse. 
+                             Please ask the Administrator to set you a new password.');
+                    }
+
+                    if ( ($is_hashed === false && (string)$row['password'] === (string)md5($password)) ||
+                         ($is_hashed !== false && (string)$row['password'] === (string)$password) ) {
+
+                        serendipity_db_query("UPDATE {$serendipity['dbPrefix']}authors
+                                                 SET password = '" . ($is_hashed === false ? serendipity_hash($password) : $password) . "',
+                                                     hashtype = 1
+                                               WHERE authorid = '" . $row['authorid'] . "'");
+                        if ($debug) fwrite($fp, date('Y-m-d H:i') . ' - Migrated user:' . $row['username'] . "\n");
+                        $is_valid_user = true;
+                    } else {
+                        continue;
+                    }                    
+                } else {
+                    if ( ($is_hashed === false && (string)$row['password'] === (string)serendipity_hash($password)) ||
+                         ($is_hashed !== false && (string)$row['password'] === (string)$password) ) {
+
+                        $is_valid_user = true;
+                        if ($debug) fwrite($fp, date('Y-m-d H:i') . ' - Validated ' . $row['password'] . ' == ' . ($is_hashed === false ? 'unhash:' . serendipity_hash($password) : 'hash:' . $password) . "\n");
+                    } else {
+                        if ($debug) fwrite($fp, date('Y-m-d H:i') . ' - INValidated ' . $row['password'] . ' == ' . ($is_hashed === false ? 'unhash:' . serendipity_hash($password) : 'hash:' . $password) . "\n");
+                        continue;
+                    }                    
+                }
+
+                // This code is only reached, if the password before is valid.
+                if ($is_valid_user) {
+                    if ($debug) fwrite($fp, date('Y-m-d H:i') . ' [sid:' . session_id() . '] - Success.' . "\n");
+                    serendipity_setCookie('old_session', session_id(), false);
+                    if (!$is_hashed) {
+                        serendipity_setAuthorToken();
+                        $_SESSION['serendipityPassword']    = $serendipity['serendipityPassword'] = $password;
+                    }
+
+                    $_SESSION['serendipityUser']        = $serendipity['serendipityUser']         = $username;
+                    $_SESSION['serendipityRealname']    = $serendipity['serendipityRealname']     = $row['realname'];
+                    $_SESSION['serendipityEmail']       = $serendipity['serendipityEmail']        = $row['email'];
+                    $_SESSION['serendipityAuthorid']    = $serendipity['authorid']                = $row['authorid'];
+                    $_SESSION['serendipityUserlevel']   = $serendipity['serendipityUserlevel']    = $row['userlevel'];
+                    $_SESSION['serendipityAuthedUser']  = $serendipity['serendipityAuthedUser']   = true;
+                    $_SESSION['serendipityRightPublish']= $serendipity['serendipityRightPublish'] = $row['right_publish'];
+                    $_SESSION['serendipityHashType']    = $serendipity['serendipityHashType']     = $row['hashtype'];
+                    
+                    serendipity_load_configuration($serendipity['authorid']);
+                    serendipity_setCookie('userDefLang', $serendipity['lang'], false);
+                    return true;
+                }
             }
-            $_SESSION['serendipityUser']        = $serendipity['serendipityUser']         = $username;
-            $_SESSION['serendipityRealname']    = $serendipity['serendipityRealname']     = $row['realname'];
-            $_SESSION['serendipityPassword']    = $serendipity['serendipityPassword']     = $password;
-            $_SESSION['serendipityEmail']       = $serendipity['serendipityEmail']        = $row['email'];
-            $_SESSION['serendipityAuthorid']    = $serendipity['authorid']                = $row['authorid'];
-            $_SESSION['serendipityUserlevel']   = $serendipity['serendipityUserlevel']    = $row['userlevel'];
-            $_SESSION['serendipityAuthedUser']  = $serendipity['serendipityAuthedUser']   = true;
-            $_SESSION['serendipityRightPublish']= $serendipity['serendipityRightPublish'] = $row['right_publish'];
-            serendipity_load_configuration($serendipity['authorid']);
-            serendipity_setCookie('userDefLang', $serendipity['lang'], false);
-            return true;
-        } else {
-            $_SESSION['serendipityAuthedUser'] = false;
-            serendipity_session_destroy();
         }
+
+        // Only reached, when proper login did not yet return true.
+        if ($debug) fwrite($fp, date('Y-m-d H:i') . ' - FAIL.' . "\n");
+        
+        $_SESSION['serendipityAuthedUser'] = false;
+        serendipity_session_destroy();
+    }
+
+    if ($debug) {
+        fwrite($fp, date('Y-m-d H:i') . ' [sid:' . session_id() . '] - Uninit' . "\n");
+        fclose($fp);
     }
 
     return false;
@@ -821,6 +883,12 @@ function serendipity_probeInstallation($item) {
                 in_array('pgsql', PDO::getAvailableDrivers())) {
                 $res['pdo-postgres'] = 'PDO::PostgreSQL';
             }
+
+            if (extension_loaded('PDO') &&
+                in_array('sqlite', PDO::getAvailableDrivers())) {
+                $res['pdo-sqlite'] = 'PDO::SQLite';
+            }
+
             if (extension_loaded('pgsql')) {
                 $res['postgres'] = 'PostgreSQL';
             }
@@ -2056,4 +2124,24 @@ function serendipity_hasPluginPermissions($plugin, $groupid = null) {
     }
 }
 
+function serendipity_hash($string) {
+    global $serendipity;
+    
+    if (empty($serendipity['hashkey'])) {
+        serendipity_set_config_var('hashkey', time(), 0);
+    }
+
+    return sha1($serendipity['hashkey'] . $string);
+}
+
+function serendipity_passwordhash($cleartext_password) {
+    global $serendipity;
+
+    if ($_SESSION['serendipityHashType'] > 0) {
+        return serendipity_hash($cleartext_password);
+    } else {
+        return md5($cleartext_password);
+    }
+}
+
 /* vim: set sts=4 ts=4 expandtab : */
