@@ -1,4 +1,4 @@
-<?php # $Id: functions_entries.inc.php 2395 2008-12-09 10:05:33Z garvinhicking $
+<?php # $Id: functions_entries.inc.php 2597 2009-11-25 20:41:43Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -722,11 +722,22 @@ function serendipity_rebuildCategoryTree($parent = 0, $left = 0) {
  * @access public
  * @param   string      The searchterm (may contain wildcards)
  * @param   int         Restrict the number of results [also uses $serendipity['GET']['page'] for pagination]
+ * @param   array       Add search Results at the top
  * @return  array       Returns the superarray of entries found
  */
-function &serendipity_searchEntries($term, $limit = '') {
+function &serendipity_searchEntries($term, $limit = '', $searchresults = '') {
     global $serendipity;
+    static $log_queries = false;
+    
+    if ($log_queries) {
+        $fp = fopen($serendipity['serendipityPath'] . '/archives/queries.csv', 'a');
+        fwrite($fp, date('Y-m-d H:i') . ';'
+                    . $_SERVER['REMOTE_ADDR'] . ';'
+                    . $term . "\n");
+        fclose($fp);
+    }
 
+    $orig_limit = $limit;
     if ($limit == '') {
         $limit = $serendipity['fetchLimit'];
     }
@@ -739,6 +750,7 @@ function &serendipity_searchEntries($term, $limit = '') {
 
     $term = serendipity_db_escape_string($term);
     $cond = array();
+    $relevance_enabled = false;
     if ($serendipity['dbType'] == 'postgres' ||
         $serendipity['dbType'] == 'pdo-postgres') {
         $cond['group']     = '';
@@ -769,6 +781,7 @@ function &serendipity_searchEntries($term, $limit = '') {
         $cond['group']    = 'GROUP BY e.id';
         $cond['distinct'] = '';
         $term             = str_replace('&quot;', '"', $term);
+        $relevance_enabled = true;
         if (preg_match('@["\+\-\*~<>\(\)]+@', $term)) {
             $cond['find_part'] = "MATCH(title,body,extended) AGAINST('$term' IN BOOLEAN MODE)";
         } else {
@@ -776,6 +789,21 @@ function &serendipity_searchEntries($term, $limit = '') {
         }
     }
 
+    switch($serendipity['searchsort']) {
+        case 'relevance':
+            if ($relevance_enabled) {
+                $cond['searchorderby'] = $cond['find_part'] . " DESC";
+            } else {
+                $cond['searchorderby'] = "timestamp DESC";
+            }
+            break;
+
+        case 'timestamp':
+        default:
+            $cond['searchorderby'] = "timestamp DESC";
+            break;
+    }
+
     $cond['and'] = " AND isdraft = 'false' " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND timestamp <= " . serendipity_db_time() : '');
     serendipity_plugin_api::hook_event('frontend_fetchentries', $cond, array('source' => 'search', 'term' => $term));
     serendipity_ACL_SQL($cond, 'limited');
@@ -793,6 +821,7 @@ function &serendipity_searchEntries($term, $limit = '') {
                             {$cond['and']}";
 
     $querystring = "SELECT {$cond['distinct']}
+                            {$cond['addkey']}
                             e.id,
                             e.authorid,
                             a.realname AS author,
@@ -812,15 +841,40 @@ function &serendipity_searchEntries($term, $limit = '') {
                     {$serendipity['fullCountQuery']}
                     {$cond['group']}
                     {$cond['having']}
-                  ORDER BY  timestamp DESC
+                  ORDER BY  {$cond['searchorderby']}
                     $limit";
 
     $search =& serendipity_db_query($querystring);
 
-    if (is_array($search)) {
-        serendipity_fetchEntryData($search);
+    //Add param searchresults at the top and remove duplicates.
+    if (is_array($searchresults)) {
+        $ids_current = array();
+        foreach($searchresults AS $idx => $data) {
+            $ids_current[$data['id']] = true;
+        }
+   
+        foreach($search AS $idx => $data) {
+            if (isset($ids_current[$data['id']])) {
+                unset($search[$idx]);
+            }
+        }
+        $search = array_merge($searchresults, $search);
     }
 
+    //if * wasn't already appended and if there are none or not enough
+    //results, search again for entries containing the searchterm as a part  
+    if (strpos($term, '*') === false) {
+        if (! is_array($search)) {
+            return serendipity_searchEntries($term.'*', $orig_limit);
+        }else if (count($search) < 4){
+            return serendipity_searchEntries($term.'*', $orig_limit, $search);
+        }
+    }
+    
+    if (is_array($search)){
+        serendipity_fetchEntryData($search);
+    }
+    
     return $search;
 }
 
@@ -869,7 +923,7 @@ function serendipity_printEntryFooter($suffix = '.html', $totalEntries = null) {
     $serendipity['smarty']->assign('footer_totalEntries', $totalEntries);
     $serendipity['smarty']->assign('footer_totalPages', $totalPages);
     $serendipity['smarty']->assign('footer_currentPage', $serendipity['GET']['page']);
-    $serendipity['smarty']->assign('footer_pageLink', serendipity_rewriteURL(implode('/', $uriArguments) . $suffix));
+    $serendipity['smarty']->assign('footer_pageLink', str_replace('%2A', '*', serendipity_rewriteURL(implode('/', $uriArguments) . $suffix)));
     $serendipity['smarty']->assign('footer_info', sprintf(PAGE_BROWSE_ENTRIES, (int)$serendipity['GET']['page'], $totalPages, $totalEntries));
 
     if ($serendipity['GET']['page'] < $totalPages) {
@@ -929,7 +983,7 @@ function serendipity_getTotalEntries() {
  * @param   boolean     Toggle whether the extended portion of an entry is requested (via $serendipity['GET']['id'] single entry view)
  * @param   boolean     Indicates if this is a preview
  * @param   string      The name of the SMARTY block that this gets parsed into
- * @param   boolean     Indicates whether the assigned smarty variables should be parsed
+ * @param   boolean     Indicates whether the assigned smarty variables should be parsed. When set to "return", no smarty parsing is done.
  * @param   boolean     Indicates whether to apply footer/header event hooks
  * @param   boolean     Indicates whether the pagination footer should be displayed
  * @param   mixed       Indicates whether the input $entries array is already grouped in preparation for the smarty $entries output array [TRUE], or if it shall be grouped by date [FALSE] or if a plugin hook shall be executed to modify data ['plugin']. This setting can also be superseded by a 'entry_display' hook.
@@ -990,9 +1044,15 @@ function serendipity_printEntries($entries, $extended = 0, $preview = false, $sm
         $dategroup =& $entries;
     }
 
-    foreach($dategroup as $properties) {
+    foreach($dategroup as $dategroup_idx => $properties) {
         foreach($properties['entries'] as $x => $_entry) {
-            $entry = &$properties['entries'][$x]; // PHP4 Compat
+            if ($smarty_fetch === 'return') {
+                $entry = &$dategroup[$dategroup_idx]['entries'][$x]; // PHP4 Compat
+            } else {
+                // DISABLED - made problems with custom plugins
+                // $entry = &$properties['entries'][$x]; // PHP4 Compat
+                $entry = &$dategroup[$dategroup_idx]['entries'][$x]; // PHP4 Compat
+            }
 
             if (!empty($entry['properties']['ep_cache_body'])) {
                 $entry['body']      = &$entry['properties']['ep_cache_body'];
@@ -1064,7 +1124,9 @@ function serendipity_printEntries($entries, $extended = 0, $preview = false, $sm
 
             if (is_array($entry['categories'])) {
                 foreach ($entry['categories'] as $k => $v) {
-                    $entry['categories'][$k]['category_link'] =  serendipity_categoryURL($entry['categories'][$k]);
+                    if (!isset($entry['categories'][$k]['category_link'])) {
+                        $entry['categories'][$k]['category_link'] =  serendipity_categoryURL($entry['categories'][$k]);
+                    }
                 }
             }
 
@@ -1130,6 +1192,10 @@ function serendipity_printEntries($entries, $extended = 0, $preview = false, $sm
         serendipity_printEntryFooter();
     }
 
+    if ($smarty_fetch === 'return') {
+        return $dategroup;    
+    }    
+    
     $serendipity['smarty']->assign_by_ref('entries', $dategroup);
     unset($entries, $dategroup);
 
@@ -1290,9 +1356,9 @@ function serendipity_updertEntry($entry) {
             }
         }
 
-        if (!serendipity_db_bool($entry['isdraft']) && !serendipity_db_bool($_entry['isdraft'])) {
+        //if (!serendipity_db_bool($entry['isdraft']) && !serendipity_db_bool($_entry['isdraft'])) {
             $entry['last_modified'] = time();
-        }
+        //}
 
         $res = serendipity_db_update('entries', array('id' => $entry['id']), $entry);
         $newEntry = 0;
@@ -1534,7 +1600,7 @@ function serendipity_printArchives() {
                 . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND timestamp <= " . serendipity_db_time() : '')
                 . (!empty($cat_sql) ? ' AND ' . $cat_sql : '')
                 . (!empty($serendipity['GET']['viewAuthor']) ? ' AND e.authorid = ' . (int)$serendipity['GET']['viewAuthor'] : '') 
-                . (!empty($cat_sql) ? " GROUP BY e.id" : '');
+                . (!empty($cat_sql) ? " GROUP BY e.id, e.timestamp" : '');
     $entries =& serendipity_db_query($q, false, 'assoc');
 
     $group = array();
@@ -1644,4 +1710,4 @@ function serendipity_getCategoryRoot($id) {
                                   AND n.categoryid = " . (int)$id . "
                              ORDER BY n.category_left DESC, p.category_left ASC");
     return $r;
-}
\ No newline at end of file
+}
