@@ -30,7 +30,7 @@ if (!defined('S9Y_FRAMEWORK_TRACKBACKS')) {
 function serendipity_printEntryForm($targetURL, $hiddens = array(), $entry = array(), $errMsg = "") {
     global $serendipity;
 
-    $serendipity['EditorBrowsers'] = '(IE|Mozilla|Opera)';
+    $serendipity['EditorBrowsers'] = '@(IE|Mozilla|Opera)@i';
 
     $draftD = '';
     $draftP = '';
@@ -155,7 +155,7 @@ function serendipity_printEntryForm($targetURL, $hiddens = array(), $entry = arr
             $template_vars['show_wysiwyg'] = true;
         }
 
-        if (eregi($serendipity['EditorBrowsers'], $_SERVER['HTTP_USER_AGENT']) ) {
+        if (preg_match($serendipity['EditorBrowsers'], $_SERVER['HTTP_USER_AGENT']) ) {
             $template_vars['wysiwyg_advanced'] = true;
         }
 
@@ -378,7 +378,7 @@ function serendipity_printEntryForm($targetURL, $hiddens = array(), $entry = arr
                 <td align="right">
 <?php
         /* Since the user has WYSIWYG editor disabled, we want to check if we should use the "better" non-WYSIWYG editor */
-        if (!$serendipity['wysiwyg'] && eregi($serendipity['EditorBrowsers'], $_SERVER['HTTP_USER_AGENT']) ) {
+        if (!$serendipity['wysiwyg'] && preg_match($serendipity['EditorBrowsers'], $_SERVER['HTTP_USER_AGENT']) ) {
 ?>
                   <script type="text/javascript" language="JavaScript">
                         document.write('<input type="button" class="serendipityPrettyButton input_button" name="insI" value="I" accesskey="i" style="font-style: italic" onclick="wrapSelection(document.forms[\'serendipityEntry\'][\'serendipity[body]\'],\'<em>\',\'</em>\')" />');
@@ -448,7 +448,7 @@ if (!$serendipity['wysiwyg']) {
                     <div id="tools_extended" style="display: none">
 <?php
         /* Since the user has WYSIWYG editor disabled, we want to check if we should use the "better" non-WYSIWYG editor */
-        if (eregi($serendipity['EditorBrowsers'], $_SERVER['HTTP_USER_AGENT']) ) {
+        if (preg_match($serendipity['EditorBrowsers'], $_SERVER['HTTP_USER_AGENT']) ) {
 ?>
                         <input type="button" class="serendipityPrettyButton input_button" name="insI" value="I" accesskey="i" style="font-style: italic" onclick="wrapSelection(document.forms['serendipityEntry']['serendipity[extended]'],'<em>','</em>')" />
                         <input type="button" class="serendipityPrettyButton input_button" name="insB" value="B" accesskey="b" style="font-weight: bold" onclick="wrapSelection(document.forms['serendipityEntry']['serendipity[extended]'],'<strong>','</strong>')" />
@@ -554,6 +554,11 @@ function serendipity_emit_htmlarea_code($item, $jsname, $spawnMulti = false) {
             $xinha = false;
         }
 
+        $xinha_custom = serendipity_getTemplateFile('my_custom.js', 'serendipityHTTPPath');
+        if (empty($xinha_custom)) {
+            $xinha_custom = 'htmlarea/my_custom.js';
+        }
+        
         if (!$init) {
 ?>
     <script type="text/javascript">
@@ -562,8 +567,12 @@ function serendipity_emit_htmlarea_code($item, $jsname, $spawnMulti = false) {
         _editor_skin = "silva";
         var editorref = '';
     </script>
-    <?php if ($xinha) { ?><script type="text/javascript" src="htmlarea/XinhaCore.js"></script>
-    <?php } else { ?><script type="text/javascript" src="htmlarea/htmlarea.js"></script>
+    <?php if ($xinha) { ?>
+    <script type="text/javascript" src="htmlarea/XinhaCore.js"></script>
+    <!-- This file can contain user customizations -->
+    <script type="text/javascript" src="<?php echo $xinha_custom; ?>"></script>
+    <?php } else { ?>
+    <script type="text/javascript" src="htmlarea/htmlarea.js"></script>
     <?php } ?>
 <?php
         }
@@ -583,6 +592,7 @@ function serendipity_emit_htmlarea_code($item, $jsname, $spawnMulti = false) {
                    (defined('LANG_DIRECTION') ? LANG_DIRECTION : 'ltr')
                  ),
 
+                 file_get_contents(serendipity_getTemplateFile('style_fallback.css', 'serendipityPath')) . 
                  file_get_contents(serendipity_getTemplateFile('htmlarea.css', 'serendipityPath'))
         );
 ?>
@@ -681,7 +691,7 @@ function serendipity_emit_htmlarea_code($item, $jsname, $spawnMulti = false) {
                         break;
                     case S9Y_WYSIWYG_TOOLBAR_MEDIA:
                     case S9Y_WYSIWYG_TOOLBAR_WEB:
-                        $toolbar[S9Y_WYSIWYG_WEB][] = $button;
+                        $toolbar[S9Y_WYSIWYG_TOOLBAR_WEB][] = $button;
                         break;
                     default:
                         $toolbar['other'][] = $button;
@@ -690,7 +700,9 @@ function serendipity_emit_htmlarea_code($item, $jsname, $spawnMulti = false) {
                 }
             }
             ?>
-        <?php if ($xinha) { ?>config<?php echo $jsname; ?>.pageStyle = '<?php echo $csscode; ?>';
+        <?php if ($xinha) { ?>
+             config<?php echo $jsname; ?>.pageStyle = '<?php echo $csscode; ?>';
+             config<?php echo $jsname; ?>.stripScripts = false;
         <?php } else { ?>config<?php echo $jsname; ?>.cssFile = '<?php echo $csscode; ?>';
         <?php } ?>
 
@@ -729,6 +741,11 @@ function serendipity_emit_htmlarea_code($item, $jsname, $spawnMulti = false) {
                   } ?>
               
         ];
+        
+        if (typeof('s9y_xinha') != 'undefined') {
+            s9y_xinha(editor<?php echo $jsname; ?>);
+        }
+
         // editor<?php echo $jsname; ?>.registerPlugin(SpellChecker);  // [SPELLCHECK]
         editor<?php echo $jsname; ?>.generate();
         editor<?php echo $jsname; ?>._textArea.className = 'serendipity_entry';
