@@ -1,4 +1,4 @@
-<?php # $Id: functions_installer.inc.php 2397 2008-12-09 10:41:48Z garvinhicking $
+<?php # $Id: functions_installer.inc.php 2520 2009-06-02 12:49:26Z brockhaus $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -282,6 +282,9 @@ function serendipity_parseTemplate($filename, $areas = null, $onlyFlags=null) {
     }
 
     $config = @include($filename);
+    if (! is_array($config)) {
+    	printf(INCLUDE_ERROR,$filename);
+    }
 
     foreach ( $config as $n => $category ) {
         /* If $areas is an array, we filter out those categories, not within the array */
