@@ -256,7 +256,7 @@ function serendipity_initPermalinks() {
     @define('PAT_FILENAME',       '0-9a-z\.\_!;,\+\-\%');
     @define('PAT_FILENAME_MATCH', '[' . PAT_FILENAME . ']+');
     @define('PAT_DIRNAME_MATCH',  '[' . PAT_FILENAME . '/]*');
-    @define('PAT_CSS',            '@/(serendipity\.css|serendipity_admin\.css)@');
+    @define('PAT_CSS',            '@/(serendipity\.css|serendipity_admin\.css)$@');
     @define('PAT_FEED',           '@/(index|atom[0-9]*|rss|b2rss|b2rdf).(rss|rdf|rss2|xml)@');
     @define('PAT_COMMENTSUB',     '@/([0-9]+)[_\-][' . PAT_FILENAME . ']*\.html@i');
 
@@ -777,7 +777,7 @@ static $indexFile = null;
     }
 
     /* Explode the path into sections, to later be able to check for arguments and add our own */
-    preg_match('/^'. preg_quote($serendipity['serendipityHTTPPath'], '/') . '(' . preg_quote($serendipity['indexFile'], '/') . '\?\/)?(' . ($wildcard ? '.+' : '[;,_a-z0-9\-*\/%\+]+') . ')/i', $uri, $_res);
+    preg_match('/^'. preg_quote($serendipity['serendipityHTTPPath'], '/') . '(' . preg_quote($serendipity['indexFile'], '/') . '\?\/)?(' . ($wildcard ? '.+' : '[!;,_a-z0-9\-*\/%\+]+') . ')/i', $uri, $_res);
     if (strlen($_res[2]) != 0) {
         $args = explode('/', $_res[2]);
         if ($args[0] == $indexFile || $args[0] == $serendipity['indexFile']) {
