@@ -419,6 +419,8 @@ function serendipity_plugin_config(&$plugin, &$bag, &$name, &$desc, &$config_nam
         $radio    = array();
         $select   = array();
         $per_row  = null;
+        $text_rows = null;
+        $input_type = null;
 
         $is_multi_select = false;
         $ctype    = $cbag->get('type');
@@ -548,6 +550,12 @@ function serendipity_plugin_config(&$plugin, &$bag, &$name, &$desc, &$config_nam
                 break;
 
             case 'string':
+                if (empty($input_type)) {
+                    $input_type = $cbag->get('input_type');
+                    if (empty($input_type)) {
+                        $input_type = "text";
+                    }
+                }
 ?>
         <tr>
             <td style="border-bottom: 1px solid #000000">
@@ -556,7 +564,7 @@ function serendipity_plugin_config(&$plugin, &$bag, &$name, &$desc, &$config_nam
             </td>
             <td style="border-bottom: 1px solid #000000" width="250">
                 <div>
-                    <input class="direction_<?php echo $lang_direction; ?> input_textbox" type="text" name="serendipity[<?php echo $postKey; ?>][<?php echo $config_item; ?>]" value="<?php echo $hvalue; ?>" size="30" />
+                    <input class="direction_<?php echo $lang_direction; ?> input_textbox" type="<?php echo $input_type; ?>" name="serendipity[<?php echo $postKey; ?>][<?php echo $config_item; ?>]" value="<?php echo $hvalue; ?>" size="30" />
                 </div>
             </td>
         </tr>
@@ -565,6 +573,12 @@ function serendipity_plugin_config(&$plugin, &$bag, &$name, &$desc, &$config_nam
 
             case 'html':
             case 'text':
+                if (empty($text_rows)) {
+                    $text_rows = $cbag->get('rows');
+                    if (empty($text_rows)) {
+                        $text_rows = 20;
+                    }
+                }
 ?>
         <tr>
             <td colspan="2"><strong><?php echo $cname; ?></strong>
@@ -575,13 +589,16 @@ function serendipity_plugin_config(&$plugin, &$bag, &$name, &$desc, &$config_nam
         <tr>
             <td colspan="2">
                 <div>
-                    <textarea class="direction_<?php echo $lang_direction; ?>" style="width: 100%" id="nuggets<?php echo $elcount; ?>" name="serendipity[<?php echo $postKey; ?>][<?php echo $config_item; ?>]" rows="20" cols="80"><?php echo $hvalue; ?></textarea>
+                    <textarea class="direction_<?php echo $lang_direction; ?>" style="width: 100%" id="nuggets<?php echo $elcount; ?>" name="serendipity[<?php echo $postKey; ?>][<?php echo $config_item; ?>]" rows="<?php echo $text_rows; ?>" cols="80"><?php echo $hvalue; ?></textarea>
                 </div>
             </td>
         </tr>
 <?php
                 if ($cbag->get('type') == 'html') {
                     $htmlnugget[] = $elcount;
+                    if (!function_exists('serendipity_emit_htmlarea_code')) {
+                        @include dirname(__FILE__) . '/functions_entries_admin.inc.php';
+                    }
                     serendipity_emit_htmlarea_code('nuggets', 'nuggets', true);
                 }
                 break;
@@ -615,6 +632,7 @@ function change_preview(id)
     var image_box = document.getElementById(id + '_preview'); 
     var filename = text_box.value;
     image_box.style.backgroundImage = 'url(' + filename + ')';
+    image_box.style.backgroundRepeat = 'no-repeat';
 }
 function choose_media(id)
 {
@@ -642,7 +660,7 @@ EOS;
 </td> </tr>
 <tr>
   <td style="border-bottom: 1px solid #000000">
-    <div id="{$config_item}_preview" style="background-image: url($value); width:$preview_width; height: $preview_height;">&nbsp;</div>
+    <div id="{$config_item}_preview" style="background-image: url($value); width:$preview_width; height: $preview_height; background-repeat: no-repeat;">&nbsp;</div>
   </td>
   <td style="border-bottom: 1px solid #000000">
     <input class="input_textbox" type="text" id="serendipity[$postKey][$config_item]" name="serendipity[$postKey][$config_item]" value="$value" onchange="change_preview('$config_item')"/>
