@@ -1,4 +1,4 @@
-<?php # $Id: functions_smarty.inc.php 2399 2008-12-12 15:50:58Z garvinhicking $
+<?php # $Id: functions_smarty.inc.php 2569 2009-08-21 08:52:50Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -188,7 +188,7 @@ function serendipity_smarty_fetchPrintEntries($params, &$smarty) {
     }
     
     if (!empty($params['entryprops'])) {
-        if (preg_match_all('@(.*)(!)?=[\'"]*(.*)[\'"]*(,|$)@imsU', $params['entryprops'], $m)) {
+        if (preg_match_all('@(.*)(!)?=[\'"]*([^\'"]+)[\'"]*(,|$)@imsU', $params['entryprops'], $m)) {
             foreach($m[0] AS $idx => $p) {
                 $params['joinown'] .= "\n JOIN {$serendipity['dbPrefix']}entryproperties 
                                           AS ep" . $idx . " 
@@ -336,6 +336,10 @@ function serendipity_smarty_fetchPrintEntries($params, &$smarty) {
                 break;
         }
     }
+    
+    if ($params['returncode'] == 'query') {
+        return print_r($entry, true);
+    }
 
     serendipity_printEntries(
         $entry,                                 // Entry data
@@ -835,7 +839,7 @@ function serendipity_smarty_getImageSize($params, &$smarty) {
  * @param   object  Smarty object
  * @return
  */
-function &serendipity_replaceSmartyVars(&$tpl_source, &$smarty) {
+function &serendipity_replaceSmartyVars($tpl_source, &$smarty) {
     $tpl_source = str_replace('$CONST.', '$smarty.const.', $tpl_source);
     return $tpl_source;
 }
@@ -967,9 +971,9 @@ function serendipity_smarty_init($vars = array()) {
                 'entry_id'                  => (isset($serendipity['GET']['id']) && is_numeric($serendipity['GET']['id'])) ? $serendipity['GET']['id'] : false,
                 'is_single_entry'           => (isset($serendipity['GET']['id']) && is_numeric($serendipity['GET']['id'])),
 
-                'blogTitle'                 => htmlspecialchars($serendipity['blogTitle']),
-                'blogSubTitle'              => (!empty($serendipity['blogSubTitle']) ? htmlspecialchars($serendipity['blogSubTitle']) : ''),
-                'blogDescription'           => htmlspecialchars($serendipity['blogDescription']),
+                'blogTitle'                 => $serendipity['blogTitle'],
+                'blogSubTitle'              => (!empty($serendipity['blogSubTitle']) ? $serendipity['blogSubTitle'] : ''),
+                'blogDescription'           => $serendipity['blogDescription'],
 
                 'serendipityHTTPPath'       => $serendipity['serendipityHTTPPath'],
                 'serendipityBaseURL'        => $serendipity['baseURL'],
