@@ -1,4 +1,4 @@
-<?php # $Id: functions_trackbacks.inc.php 2095 2008-01-20 14:16:06Z garvinhicking $
+<?php # $Id: functions_trackbacks.inc.php 2551 2009-07-14 11:40:16Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -130,7 +130,7 @@ function _serendipity_send($loc, $data, $contenttype = null) {
     serendipity_plugin_api::hook_event('backend_http_request', $options, 'trackback_send');
     serendipity_request_start();
 
-    $req = &new HTTP_Request($uri, $options);
+    $req = new HTTP_Request($uri, $options);
     if (isset($contenttype)){
        $req->addHeader('Content-Type', $contenttype);
     }
@@ -271,7 +271,7 @@ global $serendipity;
     $options = array('allowRedirects' => true, 'maxRedirects' => 5, 'method' => 'GET');
     serendipity_plugin_api::hook_event('backend_http_request', $options, 'trackback_detect');
     serendipity_request_start();
-    $req = &new HTTP_Request($parsed_loc, $options);
+    $req = new HTTP_Request($parsed_loc, $options);
     $res = $req->sendRequest();
 
     if (PEAR::isError($res)) {
@@ -503,7 +503,7 @@ function fetchPingbackData( &$comment) {
     if (function_exists('serendipity_request_start')) serendipity_request_start();
     
     // Request the page
-    $req = &new HTTP_Request($url, array('allowRedirects' => true, 'maxRedirects' => 5, 'timeout' => 20, 'readTimeout' => array(5,0)));
+    $req = new HTTP_Request($url, array('allowRedirects' => true, 'maxRedirects' => 5, 'timeout' => 20, 'readTimeout' => array(5,0)));
 
     // code 200: OK, code 30x: REDIRECTION
     $responses = "/(200 OK)|(30[0-9] Found)/"; // |(30[0-9] Moved)
@@ -703,6 +703,8 @@ function serendipity_handle_references($id, $author, $title, $text, $dry_run = f
 
     // Make trackback URL
     $url = serendipity_archiveURL($id, $title, 'baseURL');
+    // Make sure that the trackback-URL does not point to https
+    $url = str_replace('https://', 'http://', $url);
 
     // Add URL references
     $locations = $matches[0];
