@@ -1,4 +1,4 @@
-<?php # $Id: plugin_api.inc.php 2316 2008-08-22 09:20:13Z garvinhicking $
+<?php # $Id: plugin_api.inc.php 2563 2009-08-11 19:53:10Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -557,7 +557,7 @@ class serendipity_plugin_api
         }
 
         // $serendipity['debug']['pluginload'][] = "Returning new $class_name($instance_id)";
-        $p =& new $class_name($instance_id);
+        $p = new $class_name($instance_id);
         if (!is_null($authorid)) {
             $p->serendipity_owner = $authorid;
         } else {
@@ -568,7 +568,10 @@ class serendipity_plugin_api
             }
         }
         
-        $p->pluginPath = $pluginPath;
+        $p->pluginPath = $p->act_pluginPath = $pluginPath;
+        if (empty($p->act_pluginPath)) {
+            $p->act_pluginPath = $class_name;
+        }
         $p->pluginFile = $pluginFile;
 
         return $p;
@@ -867,6 +870,8 @@ class serendipity_plugin_api
             }
         }
 
+        serendipity_plugin_api::hook_event('frontend_sidebar_plugins', $pluginData, $addData);
+
         $serendipity['smarty']->assign_by_ref('plugindata', $pluginData);
         $serendipity['smarty']->assign('pluginside', ucfirst($side));
 
@@ -1006,6 +1011,11 @@ class serendipity_plugin_api
         // skip the execution of any follow-up plugins.
         $plugins = serendipity_plugin_api::get_event_plugins();
 
+        if (function_exists('serendipity_plugin_api_pre_event_hook')) {
+            $apifunc = 'serendipity_plugin_api_pre_event_hook';
+            $apifunc($event_name, $bag, $eventData, $addData);
+        }
+        
         if (is_array($plugins)) {
             // foreach() operates on copies of values, but we want to operate on references, so we use while()
             @reset($plugins);
@@ -1028,6 +1038,12 @@ class serendipity_plugin_api
                     $plugin_data['p']->event_hook($event_name, $bag, $eventData, $addData);
                 }
             }
+
+            if (function_exists('serendipity_plugin_api_event_hook')) {
+                $apifunc = 'serendipity_plugin_api_event_hook';
+                $apifunc($event_name, $bag, $eventData, $addData);
+            }
+
         }
 
         return true;
@@ -1154,6 +1170,7 @@ class serendipity_plugin
     var $content_class = 'serendipitySideBarContent';
     var $title         = null;
     var $pluginPath    = null;
+    var $act_pluginPath= null;
     var $pluginFile    = null;
     var $serendipity_owner = null;
 
