@@ -1,4 +1,4 @@
-<?php # $Id: config_local.inc.php 2371 2008-11-12 13:32:24Z garvinhicking $
+<?php # $Id: config_local.inc.php 2592 2009-10-27 09:08:48Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -290,7 +290,7 @@
                                     array('var'         => 'pass',
                                           'title'       => INSTALL_PASSWORD,
                                           'description' => INSTALL_PASSWORD_DESC,
-                                          'type'        => 'protected',
+                                          'type'        => 'fullprotected',
                                           'default'     => 'john',
                                           'permission'  => 'siteConfiguration',
                                           'flags'       => array('installOnly', 'local', 'simpleInstall')),
@@ -417,6 +417,13 @@
                                           'default'     => 15,
                                           'permission'  => 'blogConfiguration'),
 
+                                    array('var'         => 'searchsort',
+                                          'title'       => QUICKSEARCH_SORT,
+                                          'description' => '',
+                                          'type'        => 'list',
+                                          'default'     => array('timestamp' => DATE, 'relevance' => QUICKSEARCH_SORT_RELEVANCE),
+                                          'permission'  => 'blogConfiguration'),
+
                                     array('var'         => 'enforce_RFC2616',
                                           'title'       => SYNDICATION_RFC2616,
                                           'description' => SYNDICATION_RFC2616_DESC,
@@ -480,8 +487,22 @@
                                           'type'        => 'list',
                                           'default'     => array(),
                                           'permission'  => 'siteConfiguration',
-                                          'flags'       => array('probeDefault')),
-
+                                          'flags'       => array('probeDefault'))
+                            ));
+    if(function_exists('date_default_timezone_set')) {
+        $res['display']['items'][] = array('var'           =>   'useServerOffset',
+                                       'title'         =>   INSTALL_OFFSET_ON_SERVER_TIME,
+                                       'description'   =>   INSTALL_OFFSET_ON_SERVER_TIME_DESC,
+                                       'type'          =>   'bool',
+                                       'default'       =>   true,
+                                       'permission'    =>   'blogConfiguration'
+                                       );
+                                       
+        
+        
+    }
+    
+    array_push( $res['display']['items'],
                                     array('var'         => 'serverOffsetHours',
                                           'title'       => INSTALL_OFFSET,
                                           'description' => INSTALL_OFFSET_DESC,
@@ -502,8 +523,8 @@
                                           'description' => INSTALL_ACL_DESC,
                                           'type'        => 'bool',
                                           'default'     => true,
-                                          'permission'  => 'blogConfiguration'),
-                            ));
+                                          'permission'  => 'blogConfiguration')
+                            );
 
     $res['imagehandling'] =
              array('title' => INSTALL_CAT_IMAGECONV,
@@ -593,7 +614,7 @@
                                           'description' => MEDIA_PROP_DESC . MEDIA_PROP_MULTIDESC,
                                           'type'        => 'string',
                                           'permission'  => 'blogConfiguration',
-                                          'default'     => 'DPI:IMAGE;RUN_LENGTH:VIDEO:AUDIO;DATE;COPYRIGHT;TITLE;COMMENT1:MULTI;COMMENT2:MULTI'),
+                                          'default'     => 'DPI:IMAGE;RUN_LENGTH:VIDEO:AUDIO;DATE;COPYRIGHT;TITLE;COMMENT1:MULTI;COMMENT2:MULTI;ALT'),
 
                                     array('var'         => 'mediaKeywords',
                                           'title'       => MEDIA_KEYWORDS,
