@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_de.inc.php 2384 2008-11-26 12:33:29Z garvinhicking $
+<?php # $Id: serendipity_lang_de.inc.php 2548 2009-07-14 09:40:11Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) Jannis Hermanns, Garvin Hicking and others
@@ -132,7 +132,7 @@
 @define('THUMBNAIL_FAILED_COPY', 'Wollte %s als Vorschaubild verwenden, aber das Kopieren schlug fehl!');
 @define('AUTHOR', 'Autor');
 @define('LAST_UPDATED', 'Zuletzt aktualisiert');
-@define('TRACKBACK_SPECIFIC', 'Trackback für spezifische URI dieses Eintrags');
+@define('TRACKBACK_SPECIFIC', 'Trackback-URL für diesen Eintrag');
 @define('DIRECT_LINK', 'Direkter Link zu diesem Eintrag');
 @define('COMMENT_ADDED', 'Kommentar wurde hinzugefügt. ');
 @define('COMMENT_ADDED_CLICK', 'Klicken Sie %shier, um zu den Kommentaren zurückzukehren%s und %shier, um das Fenster zu schließen%s.');
@@ -582,7 +582,7 @@
 @define('INSTALL_SHOWFUTURE_DESC', 'Falls aktiviert, werden auch die Einträge angezeigt, deren Datum in der Zukunft liegt. Standardmäßig werden solche Einträge versteckt und erscheinen erst, wenn der entsprechende Zeitpunkt erreicht wird.');
 @define('INSTALL_DBPERSISTENT', 'Persistente Verbindungen nutzen');
 @define('INSTALL_DBPERSISTENT_DESC', 'Aktiviert die Nutzung einer persistenten Datenbankverbindung. Mehr dazu in der <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">PHP-Dokumentation</a>. Üblicherweise wird diese Einstellung nicht empfohlen.');
-@define('NO_IMAGES_FOUND', 'Keine Bilder gefunden');
+@define('NO_IMAGES_FOUND', 'Keine Mediendaten gefunden');
 @define('PERSONAL_SETTINGS', 'Eigene Einstellungen');
 @define('REFERER', 'Referrer');
 @define('NOT_FOUND', 'Nicht gefunden');
@@ -933,9 +933,27 @@
 @define('PLUGIN_DOCUMENTATION', 'Dokumentation');
 @define('PLUGIN_DOCUMENTATION_LOCAL', 'Lokale Dokumentation');
 @define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Versionsgeschichte');
-@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
-@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
-@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
-@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
-@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
-@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Großes Bild');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Zeige ein (großes) Bild über den Feeds im Sidebar, volle oder absolute URL zur Bilddatei eingeben');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Angezeigter Name für "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Optional benutzerdefinierten Namen für die Feeds eingeben (Vorgabe ist "feed" wenn leer)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Anzeigename für "Kommentar" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Optional benutzerdefinierten Namen für den Kommentar-Feed eingeben');
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD', '(ist eine absolute URL mit http://... eingetragen, wird diese URL wird als Umleitungsziel verwendet, wenn die "Erzwingen" Option für FeedBurner eingeschaltet ist. Hinweis: Das kann auch eine URL sein, die auf andere Ziele als FeedBurner verweist. Für die neuen Google FeedBurner Feeds muss http://feeds2.feedburner.com/yourfeedname eigetragen werden)');
+
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD2', '(Wenn diese Option auf "Erzwingen" gesetzt ist, wird der RSS Feed an einen anderen Webservice weitergeleitet, wie z.B. (aber nicht nur) FeedBurner. Siehe die untenstehende Option "Feedburner ID" um die absolute URL einzutragen)');
+@define('COMMENTS_FILTER_NEED_CONFIRM', 'Zu bestätigende');
+
+// Next lines were translated on 2009/06/03
+@define('DELETE_FILE_FAIL', 'Kann das Bild namens <b>%s</b> nicht löschen');
+@define('INSTALL_OFFSET_ON_SERVER_TIME', 'Worauf basiert die Zeitdifferenz zur Server-Zeitzone?');
+@define('INSTALL_OFFSET_ON_SERVER_TIME_DESC', 'Eintragszeiten nach Server-Zeitzone eintragen oder nicht. YES wählt die Server-Zeitzone als Basis, NO wählt GMT.');
+@define('NOT_WRITABLE_SPARTACUS', ' (Nur notwendig wenn Spartacus zur Plugin-Installation über das Internet genutzt werden soll)');
+@define('MEDIA_ALT', 'ALT-Attribut (Bildinhalt oder Kurzbeschreibung)');
+@define('MEDIA_PROPERTY_ALT', 'Bildinhalt (Zusammenfassung für das ALT-Attribut)');
+@define('MEDIA_TITLE', 'TITLE-Attribut (wird beim Überfahren mit der Maus angezeigt)');
+
+@define('QUICKSEARCH_SORT', 'How should search-results be sorted?');
+
+@define('QUICKSEARCH_SORT_RELEVANCE', 'Relevance');
+
