@@ -915,27 +915,41 @@
 @define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS importálása, PHP5 szükséges, és lehet hogy sok memóriát igényel');
 @define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
 
-@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
-@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
-@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
-@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
-@define('BADTOKEN', 'Invalid Moderation Link'); 
+@define('COMMENT_TOKENS', 'Tokenek használata a hozzászólások moderálásához?');
+@define('COMMENT_TOKENS_DESC', 'Amennyiben tokeneket használunk, a hozzászólásokat elfogadhatjuk vagy törölhetjük az emailben kapott linkre kattintva a blogba való bejelentkezés nélkül. Ez egy kényelmi funkció, de amennyiben egy ilyen email illetéktelenek kezébe kerül, ők is manipulálhatnak a kérdéses hozzászólásokkal további azonosítás nélkül.');
+@define('COMMENT_NOTOKENMATCH', 'A moderációs link lejárt, vagy a #%s számú hozzászólás már elfogadott/törölt');
+@define('TRACKBACK_NOTOKENMATCH', 'A moderációs link lejárt, vagy a #%s számú visszahivatkozás már elfogadott/törölt');
+@define('BADTOKEN', 'Érvénytelen moderációs link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nÚj hozzászólást küldtél ehhez: \"%s\". A hozzászólásod ez volt:\n\n%s\n\nA blog tulajdonosa engedélyezte az email-es ellenőrzést, így a következő linkre kell kattintanod hogy azonosítsd a hozzászólásodat:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nÚj hozzászólást küldtél ehhez: \"%s\". A hozzászólásod ez volt:\n\n%s\n\nA blog tulajdonosa engedélyezte az egyszeri email-es ellenőrzést, így a következő linkre kell kattintanod hogy azonosítsd a hozzászólásodat:\n<%s>\n\nMiután megtetted ezt, küldhetsz hozzászólásokat a felhasználóneveddel és email címeddel anélkül hogy újabb azonosító emailt kapnál.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Double-Opt In használata a hozzászólásokra való feliratkozásnál?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'Ha ez az opció engedélyezve van, akkor új hozzászólás esetén ha a küldő értesítést szeretne kapni a bejegyzéshez érkező újabb hozzászólásokról email-ben, meg kell erősítenie a feliratkozását a bejegyzéshez. Ez a Double-Opt In eljárás szükséges pl. a német törvények szerint például.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nÉrtesítést kértél új hozzászólások érkezéséről a következő bejegyzéshez: \"%s\" (<%s>). A feliratkozás elfogadásához (\"Double Opt In\") kattints erre a linkre:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'A hozzászólásokról szóló értesítésekre való feliratkozásodat sikeresen megerősítetted.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'A hozzászólásod megerősítése sikeresen megtörtént.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'A hozzászólásokról szóló értesítésekre való feliratkozásodat nem sikerült igazolni. Kérlek ellenőrizd az ehhez kapott linket. Ha ezt 3 hétnél régebben kaptad, kérned kell egy új igazoló linket tartalmazó levelet.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'A hozzászólásod jóváhagyása nem sikerült. Kérlek ellenőrizd az erre használt linket. Ha ezt régebben kaptad mint 3 hét, kérned kell egy újat.');
+@define('PLUGIN_DOCUMENTATION', 'Dokumentáció');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Helyi dokumentáció');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Verzió történet');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Nagy kép');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Megjelenít egy (nagy) képet az rss feed tetején, itt adhatod meg a teljes vagy abszolút útvonalat a képhez.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Megjelenített név a "feed"-hez');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Add meg az egyedi nevet a feed-ekhez (alapértelmezetten "feed")');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Megjelenített név a "hozzászólás" feed-hez');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Add meg az egyedi nevet a "hozzászólás" feed-ekhez');
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD', '(If you enter an absolute URL with http://... here, this URL will be used as the redirection target in case you have enabled the "Force" option for FeedBurner. Note that this can also be a URL independent to FeedBurner. For new Google FeedBurner feeds, you need to enter http://feeds2.feedburner.com/yourfeedname here)');
+
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD2', 'If you set this option to "Force" you can forward the RSS feed to any webservice, not only FeedBurner. Look at the option "Feedburner ID" below to enter an absolute URL)');
+@define('COMMENTS_FILTER_NEED_CONFIRM', 'Pending user confirmation');
+@define('NOT_WRITABLE_SPARTACUS', ' (Only required when you plan to use Spartacus plugin for remote plugin download)');
+@define('MEDIA_ALT', 'ALT-Attribute (depiction or short description)');
+@define('MEDIA_PROPERTY_ALT', 'Depiction (summary for ALT-Attribute)');
+
+@define('MEDIA_TITLE', 'TITLE-Attribute (will be displayed on mouse over)');
+
+@define('QUICKSEARCH_SORT', 'How should search-results be sorted?');
+
+@define('QUICKSEARCH_SORT_RELEVANCE', 'Relevance');
 
-@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
-@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
-@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
-@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
-@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
-@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
-@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
-@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
-@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
-@define('PLUGIN_DOCUMENTATION', 'Documentation');
-@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
-@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
-@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
-@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
-@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
-@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
-@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
-@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
