@@ -1,10 +1,10 @@
-<?php # $Id: serendipity_lang_bg.inc.php 2405 2008-12-18 10:55:57Z garvinhicking $
+<?php # $Id: serendipity_lang_bg.inc.php 2575 2009-08-24 08:24:19Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) 2004 Bogomil Shopov <bogomil@spisanie.com>
 # http://www.purplerain.org/nb/
 # Ognyan Kulev <ogi@fmi.uni-sofia.bg>, 2005
-# Ivan Cenov <JWalker@hotmail.bg>, 2005-2007
+# Ivan Cenov <JWalker@hotmail.bg>, 2005-2009
 /* vim: set sts=4 ts=4 expandtab : */
 
 @define('LANG_CHARSET', 'windows-1251');
@@ -541,6 +541,8 @@ $i18n_filename_to   = array('-', 'a', 'A', 'b', 'B', 'v', 'V', 'g', 'G', 'd', 'D
 @define('INSTALL', '');
 @define('ALREADY_INSTALLED', '  ');
 @define('SELECT_A_PLUGIN_TO_ADD', ' ,    ');
+@define('INSTALL_OFFSET_ON_SERVER_TIME', '     ?');
+@define('INSTALL_OFFSET_ON_SERVER_TIME_DESC', '        .  \'\'        GMT.');
 @define('INSTALL_OFFSET', '   ');
 @define('STICKY_POSTINGS', ' ');
 @define('INSTALL_FETCHLIMIT', '     ');
@@ -923,12 +925,26 @@ $i18n_filename_to   = array('-', 'a', 'A', 'b', 'B', 'v', 'V', 'g', 'G', 'd', 'D
 @define('NOTIFICATION_CONFIRM_MAIL', '      .');
 @define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', '        .   ,   .          ,      email  .');
 @define('NOTIFICATION_CONFIRM_MAIL_FAIL', '      .    ,   .          ,       .');
-@define('PLUGIN_DOCUMENTATION', 'Documentation');
-@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
-@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
-@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
-@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
-@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
-@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
-@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
-@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
+@define('PLUGIN_DOCUMENTATION', '');
+@define('PLUGIN_DOCUMENTATION_LOCAL', ' ');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', '  ');
+@define('SYNDICATION_PLUGIN_BIGIMG', ' ');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', '  ()      ,     URL  .');
+@define('SYNDICATION_PLUGIN_FEEDNAME', '  ');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', '    (  "feed",   )');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', '    ');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', '     ');
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD', '(   URL  http://... ,  URL       ,     "Force"  FeedBurner. ,   URL      FeedBurner.   Google FeedBurner ,     http://feeds2.feedburner.com/yourfeedname)');
+
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD2', '     "Force",     RSS    webservice,    FeedBurner.   "Feedburner ID" -     URL)');
+@define('COMMENTS_FILTER_NEED_CONFIRM', '    ');
+@define('NOT_WRITABLE_SPARTACUS', ' (Only required when you plan to use Spartacus plugin for remote plugin download)');
+@define('MEDIA_ALT', 'ALT-Attribute (depiction or short description)');
+@define('MEDIA_PROPERTY_ALT', 'Depiction (summary for ALT-Attribute)');
+
+@define('MEDIA_TITLE', 'TITLE-Attribute (will be displayed on mouse over)');
+
+@define('QUICKSEARCH_SORT', 'How should search-results be sorted?');
+
+@define('QUICKSEARCH_SORT_RELEVANCE', 'Relevance');
+
