@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_da.inc.php 2405 2008-12-18 10:55:57Z garvinhicking $
+<?php # $Id: serendipity_lang_da.inc.php 2575 2009-08-24 08:24:19Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) by Tom Sommer, <ts@dreamcoder.dk>
@@ -940,3 +940,17 @@
 @define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
 @define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
 @define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD', '(If you enter an absolute URL with http://... here, this URL will be used as the redirection target in case you have enabled the "Force" option for FeedBurner. Note that this can also be a URL independent to FeedBurner. For new Google FeedBurner feeds, you need to enter http://feeds2.feedburner.com/yourfeedname here)');
+
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD2', 'If you set this option to "Force" you can forward the RSS feed to any webservice, not only FeedBurner. Look at the option "Feedburner ID" below to enter an absolute URL)');
+@define('COMMENTS_FILTER_NEED_CONFIRM', 'Pending user confirmation');
+@define('NOT_WRITABLE_SPARTACUS', ' (Only required when you plan to use Spartacus plugin for remote plugin download)');
+@define('MEDIA_ALT', 'ALT-Attribute (depiction or short description)');
+@define('MEDIA_PROPERTY_ALT', 'Depiction (summary for ALT-Attribute)');
+
+@define('MEDIA_TITLE', 'TITLE-Attribute (will be displayed on mouse over)');
+
+@define('QUICKSEARCH_SORT', 'How should search-results be sorted?');
+
+@define('QUICKSEARCH_SORT_RELEVANCE', 'Relevance');
+
