@@ -915,27 +915,41 @@
 @define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS importlsa, PHP5 szksges, s lehet hogy sok memrit ignyel');
 @define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
 
-@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
-@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
-@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
-@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
-@define('BADTOKEN', 'Invalid Moderation Link'); 
+@define('COMMENT_TOKENS', 'Tokenek hasznlata a hozzszlsok moderlshoz?');
+@define('COMMENT_TOKENS_DESC', 'Amennyiben tokeneket hasznlunk, a hozzszlsokat elfogadhatjuk vagy trlhetjk az emailben kapott linkre kattintva a blogba val bejelentkezs nlkl. Ez egy knyelmi funkci, de amennyiben egy ilyen email illetktelenek kezbe kerl, k is manipullhatnak a krdses hozzszlsokkal tovbbi azonosts nlkl.');
+@define('COMMENT_NOTOKENMATCH', 'A modercis link lejrt, vagy a #%s szm hozzszls mr elfogadott/trlt');
+@define('TRACKBACK_NOTOKENMATCH', 'A modercis link lejrt, vagy a #%s szm visszahivatkozs mr elfogadott/trlt');
+@define('BADTOKEN', 'rvnytelen modercis link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nj hozzszlst kldtl ehhez: \"%s\". A hozzszlsod ez volt:\n\n%s\n\nA blog tulajdonosa engedlyezte az email-es ellenrzst, gy a kvetkez linkre kell kattintanod hogy azonostsd a hozzszlsodat:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nj hozzszlst kldtl ehhez: \"%s\". A hozzszlsod ez volt:\n\n%s\n\nA blog tulajdonosa engedlyezte az egyszeri email-es ellenrzst, gy a kvetkez linkre kell kattintanod hogy azonostsd a hozzszlsodat:\n<%s>\n\nMiutn megtetted ezt, kldhetsz hozzszlsokat a felhasznlneveddel s email cmeddel anlkl hogy jabb azonost emailt kapnl.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Double-Opt In hasznlata a hozzszlsokra val feliratkozsnl?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'Ha ez az opci engedlyezve van, akkor j hozzszls esetn ha a kld rtestst szeretne kapni a bejegyzshez rkez jabb hozzszlsokrl email-ben, meg kell erstenie a feliratkozst a bejegyzshez. Ez a Double-Opt In eljrs szksges pl. a nmet trvnyek szerint pldul.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nrtestst krtl j hozzszlsok rkezsrl a kvetkez bejegyzshez: \"%s\" (<%s>). A feliratkozs elfogadshoz (\"Double Opt In\") kattints erre a linkre:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'A hozzszlsokrl szl rtestsekre val feliratkozsodat sikeresen megerstetted.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'A hozzszlsod megerstse sikeresen megtrtnt.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'A hozzszlsokrl szl rtestsekre val feliratkozsodat nem sikerlt igazolni. Krlek ellenrizd az ehhez kapott linket. Ha ezt 3 htnl rgebben kaptad, krned kell egy j igazol linket tartalmaz levelet.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'A hozzszlsod jvhagysa nem sikerlt. Krlek ellenrizd az erre hasznlt linket. Ha ezt rgebben kaptad mint 3 ht, krned kell egy jat.');
+@define('PLUGIN_DOCUMENTATION', 'Dokumentci');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Helyi dokumentci');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Verzi trtnet');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Nagy kp');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Megjelent egy (nagy) kpet az rss feed tetejn, itt adhatod meg a teljes vagy abszolt tvonalat a kphez.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Megjelentett nv a "feed"-hez');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Add meg az egyedi nevet a feed-ekhez (alaprtelmezetten "feed")');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Megjelentett nv a "hozzszls" feed-hez');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Add meg az egyedi nevet a "hozzszls" feed-ekhez');
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD', '(If you enter an absolute URL with http://... here, this URL will be used as the redirection target in case you have enabled the "Force" option for FeedBurner. Note that this can also be a URL independent to FeedBurner. For new Google FeedBurner feeds, you need to enter http://feeds2.feedburner.com/yourfeedname here)');
+
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD2', 'If you set this option to "Force" you can forward the RSS feed to any webservice, not only FeedBurner. Look at the option "Feedburner ID" below to enter an absolute URL)');
+@define('COMMENTS_FILTER_NEED_CONFIRM', 'Pending user confirmation');
+@define('NOT_WRITABLE_SPARTACUS', ' (Only required when you plan to use Spartacus plugin for remote plugin download)');
+@define('MEDIA_ALT', 'ALT-Attribute (depiction or short description)');
+@define('MEDIA_PROPERTY_ALT', 'Depiction (summary for ALT-Attribute)');
+
+@define('MEDIA_TITLE', 'TITLE-Attribute (will be displayed on mouse over)');
+
+@define('QUICKSEARCH_SORT', 'How should search-results be sorted?');
+
+@define('QUICKSEARCH_SORT_RELEVANCE', 'Relevance');
 
-@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
-@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
-@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
-@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
-@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
-@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
-@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
-@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
-@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
-@define('PLUGIN_DOCUMENTATION', 'Documentation');
-@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
-@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
-@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
-@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
-@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
-@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
-@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
-@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
