@@ -88,7 +88,7 @@
 @define('ERROR_UNKNOWN_NOUPLOAD', 'Am dat peste o eroare necunoscută, nu am încărcat fişierul. Poate că mărimea fişierului este mai mare decât maximul admis de server. Ia legătură cu ISP-ul tău sau editează fişierul php.ini pentru a permite imagini mai mari.');
 @define('GO', 'Du-te!');
 @define('NEWSIZE', 'Noua mărime: ');
-@define('RESIZE_BLAHBLAH', '<b>Redimensionează %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>Redimensionează %s</b>');
 @define('ORIGINAL_SIZE', 'Mărime originală: <i>%sx%s</i> pixel');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Aici poţi ajusta mărimea imaginii. Dacă vrei să redimensionezi imaginea proporţional, introdu o valoare doar în una din cele 2 câmpuri şi apasă tastat TAB --  Voi calcula automat cealaltă mărime astfel încât proporţiile imaginii să nu fie alterate</p>');
 @define('QUICKJUMP_CALENDAR', 'Calendar Rapid');
@@ -202,6 +202,10 @@
 @define('RESIZING', 'Redimensionez');
 @define('RESIZE_DONE', 'Gata (am redimensionat %s imagini).');
 @define('SYNCING', 'Sincronizez baza de date cu directorul cu imagini');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', 'Gata (am sincronizat %s imagini).');
 @define('FILE_NOT_FOUND', 'Nu pot localiza fişierul denumit <b>%s</b>, poate că a fost şters deja ?');
 @define('ABORT_NOW', 'Abandonează acum');
@@ -245,7 +249,7 @@
 @define('PUBLISH', 'Publică');
 @define('PREVIEW', 'Previzualizare');
 @define('DATE', 'Data');
-@define('DATE_FORMAT_2', 'd-m-Y H:i'); // Needs to be ISO 8601 compliant for date conversion!
+@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
 @define('DATE_INVALID', 'Avertisment: Data specificată de tine este invalidă. Trebuie să fie în format YYYY-MM-DD HH:MM.');
 @define('CATEGORY_PLUGIN_DESC', 'Arată o listă cu categoriile.');
 @define('ALL_AUTHORS', 'Toţi autorii');
@@ -328,6 +332,10 @@
 @define('TOP_LEVEL', 'Însemnare');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
 @define('PERMISSIONS', 'Permisiuni');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 @define('SETTINGS_SAVED_AT', 'Noile preferinţe au fost salvate în %s');
 
 /* DATABASE SETTINGS */
@@ -413,6 +421,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', 'Miniaturile vor fi numite după formatul: numeoriginal.[suffix].extensie');
 @define('INSTALL_THUMBWIDTH', 'Dimensiuni miniaturi');
 @define('INSTALL_THUMBWIDTH_DESC', 'Valori statice maxime pentru miniaturile auto-generate');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Detalii personale');
@@ -677,7 +693,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Permalink Author URL structure');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Here you can define the relative URL structure begining from your base URL to where entries from certain authors may become available. You can use the variables %id%, %realname%, %username%, %email% and any other characters.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Permalink Category URL structure');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Here you can define the relative URL structure begining from your base URL to where entries from certain categories may become available. You can use the variables %id%, %name%, %description% and any other characters.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Here you can define the relative URL structure begining from your base URL to where entries from certain categories may become available. You can use the variables %id%, %name%, %parentname%, %description% and any other characters.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'Permalink RSS-Feed Category URL structure');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Here you can define the relative URL structure begining from your base URL to where RSS-feeds frmo certain categories may become available. You can use the variables %id%, %name%, %description% and any other characters.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Path to archives');
@@ -690,8 +706,6 @@
 @define('INSTALL_PERMALINK_PLUGINPATH', 'Path to single plugin');
 @define('INSTALL_PERMALINK_ADMINPATH', 'Path to admin');
 @define('INSTALL_PERMALINK_SEARCHPATH', 'Path to search');
-@define('USERCONF_CREATE', 'Forbid creating entries?');
-@define('USERCONF_CREATE_DESC', 'If selected, the user may not create new entries');
 @define('INSTALL_CAL', 'Calendar Type');
 @define('INSTALL_CAL_DESC', 'Choose your desired Calendar format');
 @define('REPLY', 'Reply');
@@ -804,3 +818,141 @@
 @define('CATEGORIES_HIDE_PARENT', 'Hide the selected parent category?');
 @define('CATEGORIES_HIDE_PARENT_DESC', 'If you restrict the listing of categories to a specific category, by default you will see that parent category within the output listing. If you disable this option, the parent category name will not be displayed.');
 @define('WARNING_NO_GROUPS_SELECTED', 'Warning: You did not select any group memberships. This would effectively log you out of the usergroup management, and thus your group memberships werde not changed.');
+@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
+@define('INSTALL_RSSFETCHLIMIT_DESC', 'Number of entries to display for each page on the RSS Feed.');
+@define('INSTAL_DB_UTF8', 'Enable DB-charset conversion');
+@define('INSTAL_DB_UTF8_DESC', 'Issues a MySQL "SET NAMES" query to indicate the required charset for the database. Turn this on or off, if you see weird characters in your blog.');
+@define('ONTHEFLYSYNCH', 'Enable on-the-fly media synchronization');
+@define('ONTHEFLYSYNCH_DESC', 'If enabled, Serendipity will compare the media database with the files stored on your server and synchronize the database and directory contents.');
+@define('USERCONF_CHECK_USERNAME_ERROR', 'The username cannot be left blank.');
+@define('FURTHER_LINKS', 'Further Links');
+@define('FURTHER_LINKS_S9Y', 'Serendipity Homepage');
+@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity Documentation');
+@define('FURTHER_LINKS_S9Y_BLOG', 'Official Blog');
+@define('FURTHER_LINKS_S9Y_FORUMS', 'Forums');
+@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
+@define('COMMENT_IS_DELETED', '(Comment removed)');
+
+@define('CURRENT_AUTHOR', 'Current author');
+
+@define('WORD_NEW', 'New');
+@define('SHOW_MEDIA_TOOLBAR', 'Show toolbar within media selector popup?');
+@define('MEDIA_KEYWORDS', 'Media keywords');
+@define('MEDIA_KEYWORDS_DESC', 'Enter a list of ";" separated words that you want to use as pre-defined keywords for media items.');
+@define('MEDIA_EXIF', 'Import EXIF/JPEG image data');
+@define('MEDIA_EXIF_DESC', 'If enabled, existing EXIF/JPEG metadata of images will be parsed and stored in the database for display in the media gallery.');
+@define('MEDIA_PROP', 'Media properties');
+
+
+@define('GO_ADD_PROPERTIES', 'Go & enter properties');
+@define('MEDIA_PROPERTY_DPI', 'DPI');
+@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
+@define('MEDIA_PROPERTY_COMMENT1', 'Short Comment');
+@define('MEDIA_PROPERTY_COMMENT2', 'Long Comment');
+@define('MEDIA_PROPERTY_TITLE', 'Title');
+@define('MEDIA_PROP_DESC', 'Enter a list of ";" separated property fields you want to define for each media file');
+@define('MEDIA_PROP_MULTIDESC', '(You can append ":MULTI" after any item to indicate that this item will contain long text instead of just some characters)');
+
+@define('STYLE_OPTIONS_NONE', 'This theme/style has no specific options. To see how your template can specify options, read the Technical Documentation on www.s9y.org about "Configuration of Theme options".');
+@define('STYLE_OPTIONS', 'Theme/Style options');
+
+@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');
+
+@define('SYNDICATION_RFC2616', 'Activate strict RFC2616 RSS-Feed compliance');
+@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also violates RFC2616. So if you set this option to "TRUE" you will comply with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
+@define('MEDIA_PROPERTY_DATE', 'Associated Date');
+@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
+@define('FILENAME_REASSIGNED', 'Automagically assigned new file name: %s');
+@define('MEDIA_UPLOAD_SIZE', 'Max. file upload size');
+@define('MEDIA_UPLOAD_SIZE_DESC', 'Enter the maximum filesize for uploaded files in bytes. This setting can be overruled by server-side settings in PHP.ini: upload_max_filesize, post_max_size, max_input_time all take precedence over this option. An empty string means to only use the server-side limits.');
+@define('MEDIA_UPLOAD_SIZEERROR', 'Error: You cannot upload files larger than %s bytes!');
+@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. width of image files for upload');
+@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Enter the maximum image width in pixels for uploaded images.');
+@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. height of image files for upload');
+@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Enter the maximum image height in pixels for uploaded images.');
+@define('MEDIA_UPLOAD_DIMERROR', 'Error: You cannot upload image files larger than %s x %s pixels!');
+
+@define('MEDIA_TARGET', 'Target for this link');
+@define('MEDIA_TARGET_JS', 'Popup window (via JavaScript, adaptive size)');
+@define('MEDIA_ENTRY', 'Isolated Entry');
+@define('MEDIA_TARGET_BLANK', 'Popup window (via target=_blank)');
+
+@define('MEDIA_DYN_RESIZE', 'Allow dynamic image resizing?');
+@define('MEDIA_DYN_RESIZE_DESC', 'If enabled, the media selector can return images in any requested size via a GET variable. The results are cached, and thus can create a large filebase if you make intensive use of it.');
+
+@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
+@define('PLUGIN_ACTIVE', 'Active');
+@define('PLUGIN_INACTIVE', 'Inactive');
+@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
+@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');
+
+@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');
+
+
+@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
+@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
+@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
+@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
+@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
+@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
+@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
+@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
+@define('USERCONF_CREATE', 'Disable user / forbid activity?');
+@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
+@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
+@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
+@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
+@define('PINGBACK_SENT', 'Pingback successful');
+@define('PINGBACK_FAILED', 'Pingback failed: %s');
+@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
+@define('SET_TO_MODERATED', 'Moderate');
+@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
+@define('CENTER', 'center');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD', '(If you enter an absolute URL with http://... here, this URL will be used as the redirection target in case you have enabled the "Force" option for FeedBurner. Note that this can also be a URL independent to FeedBurner. For new Google FeedBurner feeds, you need to enter http://feeds2.feedburner.com/yourfeedname here)');
+
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD2', 'If you set this option to "Force" you can forward the RSS feed to any webservice, not only FeedBurner. Look at the option "Feedburner ID" below to enter an absolute URL)');
+@define('COMMENTS_FILTER_NEED_CONFIRM', 'Pending user confirmation');
+@define('NOT_WRITABLE_SPARTACUS', ' (Only required when you plan to use Spartacus plugin for remote plugin download)');
+@define('MEDIA_ALT', 'ALT-Attribute (depiction or short description)');
+@define('MEDIA_PROPERTY_ALT', 'Depiction (summary for ALT-Attribute)');
+
+@define('MEDIA_TITLE', 'TITLE-Attribute (will be displayed on mouse over)');
+
+@define('QUICKSEARCH_SORT', 'How should search-results be sorted?');
+
+@define('QUICKSEARCH_SORT_RELEVANCE', 'Relevance');
+
