@@ -90,7 +90,7 @@
 @define('ERROR_UNKNOWN_NOUPLOAD', 'Bilinmeyen hata oluştu, dosya yüklenemedi.Dosyanız sunucunuzda izin verilen boyuttan daha büyük olabilir.Servis sağlayıcınızdan araştırın ya da php.ini dosyanızı daha büyük boyutta dosya yüklenmesine izin verecek şekilde ayarlayın.');
 @define('GO', 'Git!');
 @define('NEWSIZE', 'Yeni boyut: ');
-@define('RESIZE_BLAHBLAH', '<b>Yeniden boyutlandır %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>Yeniden boyutlandır %s</b>');
 @define('ORIGINAL_SIZE', 'Özgün boyut: <i>%sx%s</i> pixel');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Burada resmi yeniden boyutlandırabilirsiniz. Eğer resim özelliklerini değiştirmek istiyorsanız,İki kutudan birine bir değer girin ve TAB tuşuna basın --  Otomatik olarak resminiz yeniden boyutlandırılacaktır</p>');
 @define('QUICKJUMP_CALENDAR', 'Ajandaya hızlı bakış');
@@ -204,6 +204,10 @@
 @define('RESIZING', 'Yeniden hizalama');
 @define('RESIZE_DONE', 'Tamamlandı (resim %s hizalandı).');
 @define('SYNCING', 'Veritabanı ile resimler dizini eşleniyor');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', 'Tamamlandı (Eşlendi %s resimler).');
 @define('FILE_NOT_FOUND', 'Başlıklı dosyaya erişilemedi <b>%s</b>, silinmiş olabilir');
 @define('ABORT_NOW', 'İptal et');
@@ -330,6 +334,10 @@
 @define('TOP_LEVEL', 'En üst bölüm');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s beslemesi');
 @define('PERMISSIONS', 'izinler');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 @define('SETTINGS_SAVED_AT', 'Yeni ayarlarınız kaydedildi %s');
 
 /* DATABASE SETTINGS */
@@ -415,6 +423,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', 'Küçükresimler izleyen şekilde adlandırılacak: original.[suffix].ext');
 @define('INSTALL_THUMBWIDTH', 'Küçükresim boyutları');
 @define('INSTALL_THUMBWIDTH_DESC', 'Küçükresim oluşturma işlemi için izin verilen enbüyük genişlik boyutu');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Kişisel bilgileriniz');
@@ -679,7 +695,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Yazarlara göre  kalıcı bağlantı için URL Adresi yapısı ');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Burada göreli URL adresi yapısı tanımlayabilirsiniz temel URL adresinizden başlayarak yazılar yazarına göre  nasıl yönlenip sıralanacak,belirleyebilirsiniz. Şu değişkenleri kullanabilirsiniz %id%, %realname%, %username%, %email% ve başka çeşitli karakterleri.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Konu Başlığına göre Kalıcı Bağlantı URL Adresi yapısı');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Burada göreli URL adresi yapısı tanımlayabilirsiniz temel URL adresinizden başlayarak yazılar konu başlıklarına göre  nasıl yönlenip sıralanacak,belirleyebilirsiniz. Şu değişkenleri kullanabilirsiniz %id%, %name%, %description% ve başka çeşitli karakterleri.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Burada göreli URL adresi yapısı tanımlayabilirsiniz temel URL adresinizden başlayarak yazılar konu başlıklarına göre  nasıl yönlenip sıralanacak,belirleyebilirsiniz. Şu değişkenleri kullanabilirsiniz %id%, %name%, %parentname%, %description% ve başka çeşitli karakterleri.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'Konu Başlığına göre RSS-Beslemeleri için Kalıcı Bağlantı URL adres yapısı');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Burada göreli URL adresi yapısı tanımlayabilirsiniz temel URL adresinizden başlayarak yazıların RSS Beslemelerinin kalıcı bağlantıları konu başlıklarına göre  nasıl yönlenip sıralanacak,belirleyebilirsiniz. Şu değişkenleri kullanabilirsiniz  %id%, %name%, %description% ve başka çeşitli karakterleri.');
 @define('INSTALL_PERMALINK_FEEDAUTHOR', ' RSS-Beslemelerin Yazarlarına göre  Kalıcı Bağlantı URL adres yapısı');
@@ -903,3 +919,43 @@
 @define('SET_TO_MODERATED', 'Moderate');
 @define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
 @define('CENTER', 'center');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD', '(If you enter an absolute URL with http://... here, this URL will be used as the redirection target in case you have enabled the "Force" option for FeedBurner. Note that this can also be a URL independent to FeedBurner. For new Google FeedBurner feeds, you need to enter http://feeds2.feedburner.com/yourfeedname here)');
+
+@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD2', 'If you set this option to "Force" you can forward the RSS feed to any webservice, not only FeedBurner. Look at the option "Feedburner ID" below to enter an absolute URL)');
+@define('COMMENTS_FILTER_NEED_CONFIRM', 'Pending user confirmation');
+@define('NOT_WRITABLE_SPARTACUS', ' (Only required when you plan to use Spartacus plugin for remote plugin download)');
+@define('MEDIA_ALT', 'ALT-Attribute (depiction or short description)');
+@define('MEDIA_PROPERTY_ALT', 'Depiction (summary for ALT-Attribute)');
+
+@define('MEDIA_TITLE', 'TITLE-Attribute (will be displayed on mouse over)');
+
+@define('QUICKSEARCH_SORT', 'How should search-results be sorted?');
+
+@define('QUICKSEARCH_SORT_RELEVANCE', 'Relevance');
+
