@@ -1,11 +1,10 @@
-<?php # $Id: lang_bg.inc.php 1419 2006-08-29 10:25:22Z jwalker $
+<?php # $Id: lang_bg.inc.php 2317 2008-08-22 13:13:01Z jwalker $
 
 /**
- *  @version $Revision: 1419 $
+ *  @version $Revision: 2317 $
  *  @author Ivan Cenov jwalker@hotmail.bg
  */
 
-
     @define('PLUGIN_EVENT_ENTRYPROPERTIES_TITLE', 'Допълнителни свойства за постингите');
     @define('PLUGIN_EVENT_ENTRYPROPERTIES_DESC', '(Кеширане, не публични постинги, sticky постинги)');
     @define('PLUGIN_EVENT_ENTRYPROPERTIES_STICKYPOSTS', 'Маркиране на този постинг като sticky');
@@ -37,3 +36,8 @@
     @define('PLUGIN_EVENT_ENTRYPROPERTIES_CUSTOMFIELDS_DESC3', 'Списъкът на достъпните допълнителни полета може да бъде редактиран в <a href="%s" target="_blank" title="' . PLUGIN_EVENT_ENTRYPROPERTIES_TITLE . '">конфигурацията</a> на приставка serendipity_event_entryproperties.');
 
     @define('PLUGIN_EVENT_ENTRYPROPERTIES_DISABLE_MARKUP', 'Забранени текстови форматирания за тази статия:');
+    @define('PLUGIN_EVENT_ENTRYPROPERTIES_EXTJOINS', 'Използване на разширено търсене в базата данни');
+    @define('PLUGIN_EVENT_ENTRYPROPERTIES_EXTJOINS_DESC', 'Ако е позволено, ще бъдат изпълнени допълнителни SQL заявки за лепкави статии, скрити статии и изтрити статии, за да бъдат използвани на лицевата страница. Ако не е нужна, забраната на тази функция ще увеличи производителността.');
+
+    @define('PLUGIN_EVENT_ENTRYPROPERTIES_SEQUENCE', 'Екран за редактиране на статии');
+    @define('PLUGIN_EVENT_ENTRYPROPERTIES_SEQUENCE_DESC', 'Тук можете да изберете кои елементи (полета) и в какъв ред да бъдат показани по време на процеса на редактиране.');
\ No newline at end of file
