@@ -1,4 +1,4 @@
-<?php # $Id: lang_de.inc.php 2030 2007-11-23 14:57:08Z garvinhicking $
+<?php # $Id: lang_de.inc.php 2516 2009-05-29 13:23:31Z garvinhicking $
 
         @define('PLUGIN_EVENT_MAILER_NAME', 'Artikel mailen');
         @define('PLUGIN_EVENT_MAILER_DESC', 'Verschickt jeden neuen Artikel im Blog via E-Mail');
@@ -15,3 +15,6 @@
         @define('PLUGIN_EVENT_MAILER_SENDING', 'Versende');
         @define('PLUGIN_EVENT_MAILER_ISTOSENDIT', 'Diesen Eintrag per E-Mail versenden');
         @define('PLUGIN_EVENT_MAILER_SENDTOALL', 'An alle Redakteure schicken');
+
+@define('PLUGIN_EVENT_MAILER_STRIPTAGS', 'Bilder und Hyperlinks beibehalten, wenn HTML entfernt wird?');
+@define('PLUGIN_EVENT_MAILER_STRIPTAGSDESC', 'Gilt nur, wenn HTML entfernt wird. Falls aktiviert, werden Bilder und Hyperlinks in der Mail enthalten bleiben (in eckigen Klammern). Falls deaktiviert, werden alle Bilder und Hyperlinks auch entfernt.');
