@@ -1,7 +1,7 @@
-<?php # $Id: lang_en.inc.php 2030 2007-11-23 14:57:08Z garvinhicking $
+<?php # $Id: lang_en.inc.php 2516 2009-05-29 13:23:31Z garvinhicking $
 
 /**
- *  @version $Revision: 2030 $
+ *  @version $Revision: 2516 $
  *  @author Translator Name <yourmail@example.com>
  *  EN-Revision: Revision of lang_en.inc.php
  */
@@ -21,3 +21,5 @@
 @define('PLUGIN_EVENT_MAILER_SENDING', 'Sending');
 @define('PLUGIN_EVENT_MAILER_ISTOSENDIT', 'Send this entry via E-Mail');
 @define('PLUGIN_EVENT_MAILER_SENDTOALL', 'Send to all authors');
+@define('PLUGIN_EVENT_MAILER_STRIPTAGS', 'Keep images and hyperlinks when removing html?');
+@define('PLUGIN_EVENT_MAILER_STRIPTAGSDESC', 'Only applies when removing HTML-tags from the mail. If enabled, images and hyperlinks will be put inside the text, when disabled those placeholders will also be removed.');
