@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_mailer.php 2033 2007-11-25 01:10:25Z garvinhicking $
+<?php # $Id: serendipity_event_mailer.php 2530 2009-06-23 13:51:26Z garvinhicking $
 
 if (IN_serendipity !== true) {
     die ("Don't hack!");
@@ -26,7 +26,7 @@ class serendipity_event_mailer extends serendipity_event
         $propbag->add('description',   PLUGIN_EVENT_MAILER_DESC);
         $propbag->add('stackable',     false);
         $propbag->add('author',        'Sebastian Nohn, Kristian Koehntopp, Garvin Hicking');
-        $propbag->add('version',       '1.51');
+        $propbag->add('version',       '1.52');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
@@ -38,7 +38,7 @@ class serendipity_event_mailer extends serendipity_event
         ));
         $propbag->add('groups', array('FRONTEND_ENTRY_RELATED'));
 
-        $config = array('what', 'mailto', 'sendtoall', 'includelink', 'striptags', 'convertp');
+        $config = array('what', 'mailto', 'sendtoall', 'includelink', 'striptags', 'convertp', 'keepstriptags');
         $propbag->add('configuration', $config);
     }
 
@@ -120,6 +120,13 @@ class serendipity_event_mailer extends serendipity_event
                 $propbag->add('default',     'false');
                 break;
 
+            case 'keepstriptags':
+                $propbag->add('type',        'boolean');
+                $propbag->add('name',        PLUGIN_EVENT_MAILER_KEEPSTRIPTAGS);
+                $propbag->add('description', PLUGIN_EVENT_MAILER_KEEPSTRIPTAGSDESC);
+                $propbag->add('default',     'true');
+                break;
+
             case 'convertp':
                 $propbag->add('type',        'boolean');
                 $propbag->add('name',        PLUGIN_EVENT_MAILER_CONVERTP);
@@ -249,8 +256,13 @@ class serendipity_event_mailer extends serendipity_event
                         }
 
                         if (serendipity_db_bool($this->get_config('striptags', false)) == true) {
-                            $mail['body'] = preg_replace('<a[^>]+href=["\']([^"\']*)["\'][^>]*>([^<]*)</a>i', "$2 [$1]", $mail['body']);
-                            $mail['body'] = preg_replace('<img[^>]+src=["\']([^"\']*)["\'][^>]*>i', "[" . IMAGE . ": $1]", $mail['body']);
+                            if (serendipity_db_bool($this->get_config('keepstriptags', true))) {
+                                $mail['body'] = preg_replace('<a[^>]+href=["\']([^"\']*)["\'][^>]*>([^<]*)</a>i', "$2 [$1]", $mail['body']);
+                                $mail['body'] = preg_replace('<img[^>]+src=["\']([^"\']*)["\'][^>]*>i', "[" . IMAGE . ": $1]", $mail['body']);
+                            } else {
+                                $mail['body'] = preg_replace('<a[^>]+href=["\']([^"\']*)["\'][^>]*>([^<]*)</a>i', "", $mail['body']);
+                                $mail['body'] = preg_replace('<img[^>]+src=["\']([^"\']*)["\'][^>]*>i', "", $mail['body']);
+                            }
                             $mail['body'] = strip_tags($mail['body']);
                         }
 
