@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_spamblock.php 2424 2009-01-13 18:00:13Z garvinhicking $
+<?php # $Id: serendipity_event_spamblock.php 2555 2009-07-15 10:57:42Z brockhaus $
 
 
 if (IN_serendipity !== true) {
@@ -39,7 +39,7 @@ var $filter_defaults;
             'smarty'      => '2.6.7',
             'php'         => '4.1.0'
         ));
-        $propbag->add('version',       '1.71');
+        $propbag->add('version',       '1.77');
         $propbag->add('event_hooks',    array(
             'frontend_saveComment' => true,
             'external_plugin'      => true,
@@ -61,6 +61,7 @@ var $filter_defaults;
             'forcemoderation',
             'forcemoderation_treat',
             'trackback_ipvalidation' ,
+            'trackback_ipvalidation_url_exclude' ,
             'forcemoderationt',
             'forcemoderationt_treat',
             'disable_api_comments',
@@ -74,6 +75,7 @@ var $filter_defaults;
             'contentfilter_emails',
             'bloggdeblacklist',
             'akismet',
+            'akismet_server',
             'akismet_filter',
             'hide_email',
             'checkmail',
@@ -121,6 +123,14 @@ var $filter_defaults;
                 $propbag->add('radio_per_row', '1');
                 break;
 
+            case 'trackback_ipvalidation_url_exclude':
+                $propbag->add('type', 'text');
+                $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_TRACKBACKIPVALIDATION_URL_EXCLUDE);
+                $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_TRACKBACKIPVALIDATION_URL_EXCLUDE_DESC);
+                $propbag->add('rows', 2);
+                $propbag->add('default', $this->get_default_exclude_urls());
+                break;
+
             case 'trackback_check_url':
                 $propbag->add('type', 'boolean');
                 $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_TRACKBACKURL);
@@ -250,9 +260,24 @@ var $filter_defaults;
                 $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_AKISMET);
                 $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_AKISMET_DESC);
                 $propbag->add('default', '');
+
+                break;
+
+            case 'akismet_server':
+                $propbag->add('type', 'radio');
+                $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_AKISMET_SERVER);
+                $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_AKISMET_SERVER_DESC);
+                // If the user has an API key, but hasn't set a server, he 
+                // must be using an older version of the plugin; default
+                // to akismet.  Otherwise, encourage adoption of the Open
+                // Source alternative, TypePad Antispam.
+                $curr_key = $this->get_config('akismet', false);
+                $propbag->add('default', (empty($curr_key) ? 'akismet' : 'tpas'));
                 $propbag->add('radio', array(
-                    'value' => array('moderate', 'reject', 'none'),
-                    'desc'  => array(PLUGIN_EVENT_SPAMBLOCK_API_MODERATE, PLUGIN_EVENT_SPAMBLOCK_API_REJECT, NONE)
+                    'value' => array('tpas', 'akismet', 'anon-tpas', 'anon-akismet'),
+                    'desc'  => array(PLUGIN_EVENT_SPAMBLOCK_SERVER_TPAS, PLUGIN_EVENT_SPAMBLOCK_SERVER_AKISMET,
+                                     PLUGIN_EVENT_SPAMBLOCK_SERVER_TPAS_ANON, PLUGIN_EVENT_SPAMBLOCK_SERVER_AKISMET_ANON
+                    )
                 ));
                 $propbag->add('radio_per_row', '1');
 
@@ -273,6 +298,7 @@ var $filter_defaults;
 
             case 'contentfilter_urls':
                 $propbag->add('type', 'text');
+                $propbag->add('rows', 3);
                 $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS);
                 $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS_DESC);
                 $propbag->add('default', $this->filter_defaults['urls']);
@@ -280,6 +306,7 @@ var $filter_defaults;
 
             case 'contentfilter_authors':
                 $propbag->add('type', 'text');
+                $propbag->add('rows', 3);
                 $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS);
                 $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS_DESC);
                 $propbag->add('default', $this->filter_defaults['authors']);
@@ -287,6 +314,7 @@ var $filter_defaults;
 
             case 'contentfilter_words':
                 $propbag->add('type', 'text');
+                $propbag->add('rows', 3);
                 $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_FILTER_WORDS);
                 $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS_DESC);
                 $propbag->add('default', $this->filter_defaults['words']);
@@ -294,6 +322,7 @@ var $filter_defaults;
 
             case 'contentfilter_emails':
                 $propbag->add('type', 'text');
+                $propbag->add('rows', 3);
                 $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_FILTER_EMAILS);
                 $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS_DESC);
                 $propbag->add('default', $this->filter_defaults['emails']);
@@ -303,7 +332,7 @@ var $filter_defaults;
                 $propbag->add('type', 'string');
                 $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_LOGFILE);
                 $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_LOGFILE_DESC);
-                $propbag->add('default', $serendipity['serendipityPath'] . 'spamblock.log');
+                $propbag->add('default', $serendipity['serendipityPath'] . 'spamblock-%Y-%m-%d.log');
                 break;
 
             case 'logtype':
@@ -400,6 +429,10 @@ var $filter_defaults;
         return true;
     }
 
+    function get_default_exclude_urls() {
+        return '^http://identi\.ca/notice/\d+$';
+        
+    }
     function htaccess_update($new_ip) {
         global $serendipity;
 
@@ -423,9 +456,9 @@ var $filter_defaults;
                 // Check if an old htaccess file existed and try to preserve its contents. Otherwise completely wipe the file.
                 if ($htaccess != '' && preg_match('@^(.*)#SPAMDENY.*Deny From.+#/SPAMDENY(.*)$@imsU', $htaccess, $match)) {
                     // Code outside from s9y-code was found.
-                    $content = trim($match[1]) . "\n#SPAMDENY\nDeny From " . implode(',', $deny) . "\n#/SPAMDENY\n" . trim($match[2]);
+                    $content = trim($match[1]) . "\n#SPAMDENY\nDeny From " . implode(' ', $deny) . "\n#/SPAMDENY\n" . trim($match[2]);
                 } else {
-                    $content = trim($htaccess) . "\n#SPAMDENY\nDeny From " . implode(',', $deny) . "\n#/SPAMDENY\n";
+                    $content = trim($htaccess) . "\n#SPAMDENY\nDeny From " . implode(' ', $deny) . "\n#/SPAMDENY\n";
                 }
                 fwrite($fp, $content);
                 fclose($fp);
@@ -443,7 +476,8 @@ var $filter_defaults;
 
         switch($where) {
             case 'akismet.com':
-                $this->log($this->logfile, $eventData['id'], 'AKISMET_SAFETY', 'Akismet verification takes place', $addData);
+                // DEBUG
+                //$this->log($this->logfile, $eventData['id'], 'AKISMET_SAFETY', 'Akismet verification takes place', $addData);
                 $ret  = array();
         		$data = array(
         		  'blog'                    => $serendipity['baseURL'],
@@ -451,7 +485,7 @@ var $filter_defaults;
         		  'referrer'                => $_SERVER['HTTP_REFERER'],
         		  'user_ip'                 => $_SERVER['REMOTE_ADDR'] != getenv('SERVER_ADDR') ? $_SERVER['REMOTE_ADDR'] : getenv('HTTP_X_FORWARDED_FOR'),
         		  'permalink'               => serendipity_archiveURL($eventData['id'], $eventData['title'], 'serendipityHTTPPath', true, array('timestamp' => $eventData['timestamp'])),
-        		  'comment_type'            => ($addData['type'] == 'NORMAL' ? 'comment' : 'trackback'),
+        		  'comment_type'            => ($addData['type'] == 'NORMAL' ? 'comment' : strtolower($addData['type'])), // second: pingback or trackback.
         		  'comment_author'          => $addData['name'],
         		  'comment_author_email'    => $addData['email'],
         		  'comment_author_url'      => $addData['url'],
@@ -466,8 +500,43 @@ var $filter_defaults;
                     'readTimeout'       => array(5,0), 
                 );
 
-                $req    = &new HTTP_Request(
-                    'http://rest.akismet.com/1.1/verify-key',
+                // Default server type to akismet, in case user has an older version of the plugin
+                // where no server was set
+                $server_type = $this->get_config('akismet_server', 'akismet');
+                $server = '';
+                $anon = false;
+
+                switch ($server_type) {
+                    case 'anon-tpas':
+                        $anon = true;
+                    case 'tpas':
+                        $server = 'api.antispam.typepad.com';
+                        break;
+    
+                    case 'anon-akismet':
+                        $anon = true;
+                    case 'akismet':
+                        $server = 'rest.akismet.com';
+                        break;
+                }
+                
+                if ($anon) {
+                    $data['comment_author'] = 'John Doe';
+                    $data['comment_author_email'] = '';
+                    $data['comment_author_url'] = '';
+                }
+
+                if (empty($server)) {
+                    $this->log($this->logfile, $eventData['id'], 'AKISMET_SERVER', 'No Akismet server found', $addData);
+                    $ret['is_spam'] = false;
+                    $ret['message'] = 'No server for Akismet request';
+                    break;
+                } else {
+                    // DEBUG
+                    //$this->log($this->logfile, $eventData['id'], 'AKISMET_SERVER', 'Using Akismet server at ' . $server, $addData);
+                }
+                $req    = new HTTP_Request(
+                    'http://' . $server . '/1.1/verify-key',
                      $opt
                 );
 
@@ -491,8 +560,8 @@ var $filter_defaults;
                     break;
                 }
 
-                $req    = &new HTTP_Request(
-                    'http://' . $api_key . '.rest.akismet.com/1.1/comment-check',
+                $req    = new HTTP_Request(
+                    'http://' . $api_key . '.' . $server . '/1.1/comment-check',
                     $opt
                 );
 
@@ -513,11 +582,13 @@ var $filter_defaults;
                 if (preg_match('@true@i', $reqdata)) {
                     $ret['is_spam'] = true;
                     $ret['message'] = $reqdata;
-                    $this->log($this->logfile, $eventData['id'], 'AKISMET_SPAM', 'Akismet API returned spam', $addData);
+                    // DEBUG
+                    //$this->log($this->logfile, $eventData['id'], 'AKISMET_SPAM', 'Akismet API returned spam', $addData);
                 } elseif (preg_match('@false@i', $reqdata)) {
                     $ret['is_spam'] = false;
                     $ret['message'] = $reqdata;
-                    $this->log($this->logfile, $eventData['id'], 'AKISMET_PASS', 'Passed Akismet verification', $addData);
+                    // DEBUG
+                    //$this->log($this->logfile, $eventData['id'], 'AKISMET_PASS', 'Passed Akismet verification', $addData);
                 } else {
                     $ret['is_spam'] = false;
                     $ret['message'] = 'Akismet API failure';
@@ -535,7 +606,7 @@ var $filter_defaults;
                 } else {
                     $data = '';
 
-                    $req    = &new HTTP_Request('http://spam.blogg.de/blacklist.txt');
+                    $req    = new HTTP_Request('http://spam.blogg.de/blacklist.txt');
 
                     if (PEAR::isError($req->sendRequest()) || $req->getResponseCode() != '200') {
                         if (file_exists($target) && filesize($target) > 0) {
@@ -840,35 +911,47 @@ var $filter_defaults;
                         $trackback_ipvalidation_option = $this->get_config('trackback_ipvalidation','moderate');
                         if (($addData['type'] == 'TRACKBACK' || $addData['type'] == 'PINGBACK') && $trackback_ipvalidation_option != 'no') {
                             $this->IsHardcoreSpammer();
-                            $parts = @parse_url($addData['url']);
-                            $tipval_method = ($trackback_ipvalidation_option == 'reject'?'REJECTED':'MODERATE');
-                            // Getting host from url successfully?
-                            if (!is_array($parts)) { // not a valid URL
-                                $this->log($logfile, $eventData['id'], $tipval_method, sprintf(PLUGIN_EVENT_SPAMBLOCK_REASON_IPVALIDATION, $addData['url'], '', ''));
-                                if ($trackback_ipvalidation_option == 'reject') {
-                                    $eventData = array('allow_comments' => false);
-                                    $serendipity['messagestack']['comments'][] = sprintf(PLUGIN_EVENT_SPAMBLOCK_REASON_IPVALIDATION, $addData['url']);
-                                    return false;
-                                } else {
-                                    $eventData['moderate_comments'] = true;
-                                    $serendipity['csuccess']        = 'moderate';
-                                    $serendipity['moderate_reason'] = sprintf(PLUGIN_EVENT_SPAMBLOCK_REASON_IPVALIDATION, $addData['url']);
+                            $exclude_urls = explode(';',$this->get_config('trackback_ipvalidation_url_exclude', $this->get_default_exclude_urls()));
+                            $found_exclude_url = false;
+                            foreach ($exclude_urls as $exclude_url) {
+                                $exclude_url = trim($exclude_url);
+                                if (empty($exclude_url)) continue; 
+                                $found_exclude_url = preg_match('@' . $exclude_url . '@',$addData['url']);
+                                if ($found_exclude_url) {
+                                    break;
                                 }
                             }
-                            $trackback_ip = preg_replace('/[^0-9.]/', '', gethostbyname($parts['host']) );
-                            $sender_ip = preg_replace('/[^0-9.]/', '', $_SERVER['REMOTE_ADDR'] );
-                            $sender_ua = ($debug ? ', ua="' . $_SERVER['HTTP_USER_AGENT'] . '"' : '') ;
-                            // Is host ip and sender ip matching?
-                            if ($trackback_ip != $sender_ip) {
-                                $this->log($logfile, $eventData['id'], $tipval_method, sprintf(PLUGIN_EVENT_SPAMBLOCK_REASON_IPVALIDATION, $parts['host'], $trackback_ip, $sender_ip  . $sender_ua), $addData);
-                                if ($trackback_ipvalidation_option == 'reject') {
-                                    $eventData = array('allow_comments' => false);
-                                    $serendipity['messagestack']['comments'][] = sprintf(PLUGIN_EVENT_SPAMBLOCK_REASON_IPVALIDATION, $parts['host'], $trackback_ip, $sender_ip . $sender_ua);
-                                    return false;
-                                } else {
-                                    $eventData['moderate_comments'] = true;
-                                    $serendipity['csuccess']        = 'moderate';
-                                    $serendipity['moderate_reason'] = sprintf(PLUGIN_EVENT_SPAMBLOCK_REASON_IPVALIDATION, $parts['host'], $trackback_ip, $sender_ip . $sender_ua);
+                            if (!$found_exclude_url) {
+                                $parts = @parse_url($addData['url']);
+                                $tipval_method = ($trackback_ipvalidation_option == 'reject'?'REJECTED':'MODERATE');
+                                // Getting host from url successfully?
+                                if (!is_array($parts)) { // not a valid URL
+                                    $this->log($logfile, $eventData['id'], $tipval_method, sprintf(PLUGIN_EVENT_SPAMBLOCK_REASON_IPVALIDATION, $addData['url'], '', ''));
+                                    if ($trackback_ipvalidation_option == 'reject') {
+                                        $eventData = array('allow_comments' => false);
+                                        $serendipity['messagestack']['comments'][] = sprintf(PLUGIN_EVENT_SPAMBLOCK_REASON_IPVALIDATION, $addData['url']);
+                                        return false;
+                                    } else {
+                                        $eventData['moderate_comments'] = true;
+                                        $serendipity['csuccess']        = 'moderate';
+                                        $serendipity['moderate_reason'] = sprintf(PLUGIN_EVENT_SPAMBLOCK_REASON_IPVALIDATION, $addData['url']);
+                                    }
+                                }
+                                $trackback_ip = preg_replace('/[^0-9.]/', '', gethostbyname($parts['host']) );
+                                $sender_ip = preg_replace('/[^0-9.]/', '', $_SERVER['REMOTE_ADDR'] );
+                                $sender_ua = ($debug ? ', ua="' . $_SERVER['HTTP_USER_AGENT'] . '"' : '') ;
+                                // Is host ip and sender ip matching?
+                                if ($trackback_ip != $sender_ip) {
+                                    $this->log($logfile, $eventData['id'], $tipval_method, sprintf(PLUGIN_EVENT_SPAMBLOCK_REASON_IPVALIDATION, $parts['host'], $trackback_ip, $sender_ip  . $sender_ua), $addData);
+                                    if ($trackback_ipvalidation_option == 'reject') {
+                                        $eventData = array('allow_comments' => false);
+                                        $serendipity['messagestack']['comments'][] = sprintf(PLUGIN_EVENT_SPAMBLOCK_REASON_IPVALIDATION, $parts['host'], $trackback_ip, $sender_ip . $sender_ua);
+                                        return false;
+                                    } else {
+                                        $eventData['moderate_comments'] = true;
+                                        $serendipity['csuccess']        = 'moderate';
+                                        $serendipity['moderate_reason'] = sprintf(PLUGIN_EVENT_SPAMBLOCK_REASON_IPVALIDATION, $parts['host'], $trackback_ip, $sender_ip . $sender_ua);
+                                    }
                                 }
                             }
                         }
@@ -876,7 +959,7 @@ var $filter_defaults;
                         // Filter Akismet Blacklist?
                         $akismet_apikey = $this->get_config('akismet');
                         $akismet        = $this->get_config('akismet_filter');
-                        if (!empty($akismet_apikey) && ($akismet == 'moderate' || $akismet == 'reject')) {
+                        if (!empty($akismet_apikey) && ($akismet == 'moderate' || $akismet == 'reject') && !isset($addData['skip_akismet'])) {
                             $spam = $this->getBlacklist('akismet.com', $akismet_apikey, $eventData, $addData);
                             if ($spam['is_spam'] !== false) {
                                 $this->IsHardcoreSpammer();
@@ -899,7 +982,7 @@ var $filter_defaults;
                             require_once S9Y_PEAR_PATH . 'HTTP/Request.php';
 
                             if (function_exists('serendipity_request_start')) serendipity_request_start();
-                            $req     = &new HTTP_Request($addData['url'], array('allowRedirects' => true, 'maxRedirects' => 5, 'readTimeout' => array(5,0)));
+                            $req     = new HTTP_Request($addData['url'], array('allowRedirects' => true, 'maxRedirects' => 5, 'readTimeout' => array(5,0)));
                             $is_valid = false;
                             if (PEAR::isError($req->sendRequest()) || $req->getResponseCode() != '200') {
                                 $is_valid = false;
@@ -930,6 +1013,7 @@ var $filter_defaults;
                             $filter_authors = explode(';', $this->get_config('contentfilter_authors', $this->filter_defaults['authors']));
                             if (is_array($filter_authors)) {
                                 foreach($filter_authors AS $filter_author) {
+                                    $filter_author = trim($filter_author);
                                     if (empty($filter_author)) {
                                         continue;
                                     }
@@ -953,6 +1037,7 @@ var $filter_defaults;
                             $filter_urls = explode(';', $this->get_config('contentfilter_urls', $this->filter_defaults['urls']));
                             if (is_array($filter_urls)) {
                                 foreach($filter_urls AS $filter_url) {
+                                    $filter_url = trim($filter_url);
                                     if (empty($filter_url)) {
                                         continue;
                                     }
@@ -976,6 +1061,7 @@ var $filter_defaults;
                             $filter_bodys = explode(';', $this->get_config('contentfilter_words', $this->filter_defaults['words']));
                             if (is_array($filter_bodys)) {
                                 foreach($filter_bodys AS $filter_body) {
+                                    $filter_body = trim($filter_body);
                                     if (empty($filter_body)) {
                                         continue;
                                     }
@@ -999,6 +1085,7 @@ var $filter_defaults;
                             $filter_emails = explode(';', $this->get_config('contentfilter_emails', $this->filter_defaults['emails']));
                             if (is_array($filter_emails)) {
                                 foreach($filter_emails AS $filter_email) {
+                                    $filter_email = trim($filter_email);
                                     if (empty($filter_email)) {
                                         continue;
                                     }
@@ -1413,6 +1500,9 @@ var $filter_defaults;
                 if (empty($logfile)) {
                     return;
                 }
+				if (strpos($logfile, '%') !== false) {
+					$logfile = strftime($logfile);
+				}
 
                 $fp = @fopen($logfile, 'a+');
                 if (!is_resource($fp)) {
