@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_spartacus.php 2378 2008-11-21 12:20:07Z garvinhicking $
+<?php # $Id: serendipity_event_spartacus.php 2580 2009-08-27 13:23:50Z garvinhicking $
 
 /************
   TODO:
@@ -39,7 +39,7 @@ class serendipity_event_spartacus extends serendipity_event
         $propbag->add('description',   PLUGIN_EVENT_SPARTACUS_DESC);
         $propbag->add('stackable',     false);
         $propbag->add('author',        'Garvin Hicking');
-        $propbag->add('version',       '2.21');
+        $propbag->add('version',       '2.22');
         $propbag->add('requirements',  array(
             'serendipity' => '0.9',
             'smarty'      => '2.6.7',
@@ -93,15 +93,15 @@ class serendipity_event_spartacus extends serendipity_event
             'xml' => array(
                 'Netmirror.org',
                 's9y.org',
-                'openmirror.org'
+//                'openmirror.org'
             ),
 
             'files' => array(
                 'Netmirror.org',
                 'SourceForge.net',
                 's9y.org',
-                'BerliOS.de (inactive)',
-                'openmirror.org'
+//                'BerliOS.de (inactive)',
+//                'openmirror.org'
             )
         );
 
@@ -109,23 +109,23 @@ class serendipity_event_spartacus extends serendipity_event
             'xml' => array(
                 'http://netmirror.org/mirror/serendipity/',
                 'http://s9y.org/mirror/',
-                'http://openmirror.org/pub/s9y/',
+//                'http://openmirror.org/pub/s9y/',
             ),
 
             'files' => array(
                 'http://netmirror.org/mirror/serendipity/',
                 'http://php-blog.cvs.sourceforge.net/*checkout*/php-blog/',
                 'http://s9y.org/mirror/',
-                'http://svn.berlios.de/viewcvs/serendipity/',
-                'http://openmirror.org/pub/s9y/',
+//                'http://svn.berlios.de/viewcvs/serendipity/',
+//                'http://openmirror.org/pub/s9y/',
             ),
 
             'files_health' => array(
                 'http://netmirror.org/'                 => 'http://netmirror.org/mirror/serendipity/last.txt',
                 'http://php-blog.cvs.sourceforge.net/'  => 'http://php-blog.cvs.sourceforge.net/*checkout*/php-blog/serendipity/docs/LICENSE',
                 'http://s9y.org/'                       => 'http://s9y.org/',
-                'http://svn.berlios.de/'                => 'http://svn.berlios.de/viewcvs/serendipity/',
-                'http://openmirror.org/'                => 'http://openmirror.org/pub/s9y/last.txt',
+//                'http://svn.berlios.de/'                => 'http://svn.berlios.de/viewcvs/serendipity/',
+//                'http://openmirror.org/'                => 'http://openmirror.org/pub/s9y/last.txt',
             )
         );
 
@@ -397,7 +397,7 @@ class serendipity_event_spartacus extends serendipity_event
             serendipity_plugin_api::hook_event('backend_http_request', $options, 'spartacus');
             serendipity_request_start();
 
-            $req = &new HTTP_Request($url, $options);
+            $req = new HTTP_Request($url, $options);
 
             if (PEAR::isError($req->sendRequest()) || $req->getResponseCode() != '200') {
                 $resolved_url = $url . ' (IP ' . $url_ip . ')';
@@ -441,7 +441,7 @@ class serendipity_event_spartacus extends serendipity_event
 
                 $health_options = $options;
                 serendipity_plugin_api::hook_event('backend_http_request', $health_options, 'spartacus_health');
-                $health_req = &new HTTP_Request($health_url, $health_options);
+                $health_req = new HTTP_Request($health_url, $health_options);
                 $health_result = $health_req->sendRequest();
                 if (PEAR::isError($health_result)) {
                     $fp = @fsockopen('www.google.com', 80, $errno, $errstr);
@@ -868,8 +868,8 @@ class serendipity_event_spartacus extends serendipity_event
                 }
 
                 $plugname = $pluginstack[$i]['template'];
-                $pluginstack[$i]['previewURL'] = $mirror . '/additional_themes/' . $plugname . '/preview.png?rev=1.9999';
-                $pluginstack[$i]['preview_fullsizeURL'] = $mirror . '/additional_themes/' . $plugname . '/preview_fullsize.jpg?rev=1.9999';
+                $pluginstack[$i]['previewURL'] = $mirror . '/additional_themes/' . $plugname . '/preview.png?revision=1.9999';
+                $pluginstack[$i]['preview_fullsizeURL'] = $mirror . '/additional_themes/' . $plugname . '/preview_fullsize.jpg?revision=1.9999';
                 $pluginstack[$i]['customURI']  = '&amp;serendipity[spartacus_fetch]=' . $plugname;
                 $pluginstack[$i]['customIcon'] = '_spartacus';
 
@@ -954,7 +954,7 @@ class serendipity_event_spartacus extends serendipity_event
         }
 
         foreach($files AS $file) {
-            $url    = $mirror . '/' . $sfloc . '/' . $file . '?rev=1.9999';
+            $url    = $mirror . '/' . $sfloc . '/' . $file . '?revision=1.9999';
             $target = $pdir . $file;
             $this->rmkdir($pdir . $plugin_to_install,$sub);
             $this->fileperm($pdir . $plugin_to_install, true);
