@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_textwiki.php 1528 2006-12-01 08:58:47Z garvinhicking $
+<?php # $Id: serendipity_event_textwiki.php 2552 2009-07-14 11:48:10Z garvinhicking $
 
 
 if (IN_serendipity !== true) {
@@ -466,7 +466,7 @@ class serendipity_event_textwiki extends serendipity_event
         $propbag->add('description',   PLUGIN_EVENT_TEXTWIKI_DESC);
         $propbag->add('stackable',     false);
         $propbag->add('author',        'Tobias Schlitt');
-        $propbag->add('version',       '1.4');
+        $propbag->add('version',       '1.5');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
@@ -619,8 +619,8 @@ class serendipity_event_textwiki extends serendipity_event
         include_once S9Y_PEAR_PATH . 'Text/Wiki.php';
 
         if (class_exists('Text_Wiki')) {
-            $this->wiki =& new Text_Wiki;
-            $this->wiki->setFormatConf('Xhtml', 'translate', HTML_SPECIALCHARS);
+            $this->wiki = new Text_Wiki;
+            $this->wiki->setFormatConf('Xhtml', 'translate', null);
             $this->wiki->setFormatConf('Xhtml', 'charset', LANG_CHARSET);
         } else {
             return false;
