@@ -1,4 +1,4 @@
-<?php # $Id: servicesdb_ja.inc.php 1396 2006-08-17 16:40:12Z elf2000 $
+<?php # $Id: servicesdb_ja.inc.php 2612 2009-12-21 06:33:10Z garvinhicking $
 
 ##########################################################################
 # serendipity - another blogger...                                       #
@@ -10,13 +10,6 @@
 ##########################################################################
 
         $servicesdb = array(
-            array(
-              'name'       => 'Myblog japan',
-              'host'       => 'ping.myblog.jp',
-              'path'       => '/',
-              'extended' => false
-            ),
-
             array(
               'name'        => 'BLOGGERS.JP',
               'host'        => 'ping.bloggers.jp',
@@ -169,7 +162,13 @@
               'host'        => 'rpc.reader.livedoor.com',
               'path'        => '/ping',
               'extended' => false
-            )
+            ),
 
+            array(
+              'name'        => 'FeedPing.net',
+              'host'        => 'rpc.feedping.net',
+              'path'        => '/',
+              'extended'    => false
+            )
         );
 ?>
