@@ -1,9 +1,13 @@
-<?php # $Id: lang_cz.inc.php 1381 2007-12-19 23:55:00 VladaAjgl $
+<?php # lang_cz.inc.php 1381.1 2009-08-15 10:30:13 VladaAjgl $
 
 /**
- *  @version $Revision: 1381 $
+ *  @version 1381.1
  *  @author Vladimr Ajgl <vlada@ajgl.cz>
  *  EN-Revision: Revision of lang_en.inc.php
+ *  @author Vladimr Ajgl <vlada@ajgl.cz>
+ *  @revisionDate 2009/05/06
+ *  @author Vladimr Ajgl <vlada@ajgl.cz>
+ *  @revisionDate 2009/08/15
  */
 
 @define('PLUGIN_EVENT_XHTMLCLEANUP_NAME', 'Oprava nejastjch XHTML chyb');
@@ -12,5 +16,5 @@
 @define('PLUGIN_EVENT_XHTMLCLEANUP_XHTML_DESC', 'Tento plugin pouv XML parsovn pro zajitn validity XHTML kdu. Toto parsovn me zpsobit, e budou validn entity (znaky) pevedeny na "unsescaped" entity (XHTML kdy). Proto plugin vechny entity znovu kduje po zpracovn textu. Vypnte tuto volbu, pokud pozorujete dvojit rekdovn!');
 @define('PLUGIN_EVENT_XHTMLCLEANUP_UTF8', 'itn UTF-8 znak?');
 @define('PLUGIN_EVENT_XHTMLCLEANUP_UTF8_DESC', 'Pokud je zapnuto, HTML entity zpsoben pevedenm znak v kdovn Unicode UTF-8 budou sprvn pevedeny nazpt na znaky UTF-8 a nebudou zakdovny do podivnch znak v zobrazen strnky.');
-
-?>
+@define('PLUGIN_EVENT_XHTMLCLEANUP_YOUTUBE', 'Vyistit kd vide z youtube?');
+@define('PLUGIN_EVENT_XHTMLCLEANUP_YOUTUBE_DESC', 'Pokud je zapnuto, pak jsou invalidn XHTML tagy generovan youtube vyezny z embed sti. Prohle pes toto vyezn zobraz video sprvn.');
\ No newline at end of file
