@@ -1,5 +1,10 @@
-<?php # $Id: lang_de.inc.php 2333 2008-09-10 10:26:36Z garvinhicking $
+<?php # lang_de.inc.php 1.0 2009-06-03 10:01:36 VladaAjgl $
 
+/**
+ *  @version 1.0
+ *  @author Konrad Bauckmeier <kontakt@dd4kids.de>
+ *  @translated 2009/06/03
+ */
         @define('PLUGIN_COMMENTS_BLAHBLAH', 'Zeigt die letzten Kommentare');
         @define('PLUGIN_COMMENTS_WORDWRAP', 'Zeilenumbruch');
         @define('PLUGIN_COMMENTS_WORDWRAP_BLAHBLAH', 'Nach wievielen Buchstaben soll ein Zeilenumbruch eingefgt werden? (Standard: 30)');
@@ -10,3 +15,6 @@
         @define('PLUGIN_COMMENTS_ABOUT', '%s zu%s');
 
         @define('PLUGIN_COMMENTS_ADDURL', 'Kommentatoren URL anzeigen bei');
+
+// Next lines were translated on 2009/06/03
+@define('PLUGIN_COMMENTS_ANONYMOUS', 'anonym');
\ No newline at end of file
