@@ -1,7 +1,7 @@
-<?php # $Id: lang_bg.inc.php 1419 2006-08-29 10:25:22Z jwalker $
+<?php # $Id: lang_bg.inc.php 1740 2007-06-28 06:20:44Z jwalker $
 
  /**
- *  @version $Revision: 1419 $
+ *  @version $Revision: 1740 $
  *  @author Ivan Cenov jwalker@hotmail.bg
  */
 
@@ -13,3 +13,5 @@
     @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_DESC', 'Само последните постинги, които не са показани на заглавната страница ще бъдат показани. (По подразбиране: последните ' . $serendipity['fetchLimit'] . ' ще бъдат прескочени)');
     @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_RADIO_ALL', 'Покажи всички');
     @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_RADIO_RECENT', 'Прескочи показаните на заглавната страница');
+    @define('PLUGIN_RECENTENTRIES_RANDOMIZE', 'Показване на случайни статии');
+    @define('PLUGIN_RECENTENTRIES_RANDOMIZE_DESC', 'Ако е установено, показва случайно избрани статии.');
