@@ -1,7 +1,7 @@
-<?php # $Id: lang_bg.inc.php 1419 2006-08-29 10:25:22Z jwalker $
+<?php # $Id: lang_bg.inc.php 1740 2007-06-28 06:20:44Z jwalker $
 
  /**
- *  @version $Revision: 1419 $
+ *  @version $Revision: 1740 $
  *  @author Ivan Cenov jwalker@hotmail.bg
  */
 
@@ -13,3 +13,5 @@
     @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_DESC', '  ,          . ( :  ' . $serendipity['fetchLimit'] . '   )');
     @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_RADIO_ALL', ' ');
     @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_RADIO_RECENT', '    ');
+    @define('PLUGIN_RECENTENTRIES_RANDOMIZE', '   ');
+    @define('PLUGIN_RECENTENTRIES_RANDOMIZE_DESC', '  ,    .');
