@@ -1,5 +1,10 @@
-<?php # $Id: lang_de.inc.php 1381 2006-08-15 10:14:56Z elf2000 $
+<?php # lang_de.inc.php 1.0 2009-06-03 10:02:21 VladaAjgl $
 
+/**
+ *  @version 1.0
+ *  @author Konrad Bauckmeier <kontakt@dd4kids.de>
+ *  @translated 2009/06/03
+ */
         @define('PLUGIN_RECENTENTRIES_TITLE', 'Aktuelle Eintrge');
         @define('PLUGIN_RECENTENTRIES_BLAHBLAH', 'Zeigt die Titel der aktuellsten Eintrge mit Datum');
         @define('PLUGIN_RECENTENTRIES_NUMBER', 'Anzahl der Eintrge');
@@ -8,3 +13,7 @@
         @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_DESC', 'Nur die neuesten Eintrge, die nicht schon auf der Hauptseite zu sehen sind, werden angezeigt. (Default: die neuesten ' . $serendipity['fetchLimit'] . ' werden bersprungen)');
         @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_RADIO_ALL', 'Alle anzeigen');
         @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_RADIO_RECENT', 'Eintrge auf der Hauptseite berspringen');
+
+// Next lines were translated on 2009/06/03
+@define('PLUGIN_RECENTENTRIES_RANDOMIZE', 'Zeige zuflligen Artikel');
+@define('PLUGIN_RECENTENTRIES_RANDOMIZE_DESC', 'Wenn aktiviert, werden zufllige Artikel ausgewhlt.');
\ No newline at end of file
