@@ -1,4 +1,4 @@
-<?php # $Id: lang_de.inc.php 1381 2006-08-15 10:14:56Z elf2000 $
+<?php # $Id: lang_de.inc.php 2517 2009-06-01 02:36:52Z brockhaus $
 
         @define('PLUGIN_SHOUTBOX_NAME', 'Shoutbox');
         @define('PLUGIN_SHOUTBOX_BLAHBLAH', 'Zeigt eine Shoutbox für beliebige Kommentare');
@@ -10,3 +10,8 @@
         @define('PLUGIN_SHOUTBOX_MAXCHARS_BLAHBLAH', 'Wieviele Zeichen sollen pro Kommentar gezeigt werden? (Standard: 120)');
         @define('PLUGIN_SHOUTBOX_MAXENTRIES', 'Anzahl an Kommentaren');
         @define('PLUGIN_SHOUTBOX_MAXENTRIES_BLAHBLAH', 'Wieviele Kommentare sollen gezeigt werden? (Standard: 15)');
+
+@define('GENERAL_PLUGIN_BOX_COLS', 				'Shoutbox Spalten');
+@define('GENERAL_PLUGIN_BOX_COLS_BLAHBLAH', 	'Spaltenanzahl, die die Shoutbox Eingabe breit sein soll.');
+@define('GENERAL_PLUGIN_BOX_ROWS', 				'Shoutbox Reihen');
+@define('GENERAL_PLUGIN_BOX_ROWS_BLAHBLAH', 	'Reihenanzahl, die die Shoutbox Eingabe lang sein soll.');
