@@ -1,9 +1,13 @@
-<?php # $Id: lang_cs.inc.php 1381 2007-12-20 01:02:00 VladaAjgl $
+<?php # lang_cs.inc.php 1381.1 2009-08-15 10:30:56 VladaAjgl $
 
 /**
- *  @version $Revision: 1381 $
+ *  @version 1381.1
  *  @author Vladimr Ajgl <vlada@ajgl.cz>
  *  EN-Revision: Revision of lang_en.inc.php
+ *  @author Vladimr Ajgl <vlada@ajgl.cz>
+ *  @revisionDate 2009/06/14
+ *  @author Vladimr Ajgl <vlada@ajgl.cz>
+ *  @revisionDate 2009/08/15
  */
 
 @define('PLUGIN_SHOUTBOX_NAME',                 'Vkink');
@@ -16,5 +20,7 @@
 @define('PLUGIN_SHOUTBOX_MAXCHARS_BLAHBLAH',    'Kolik znak z kadho pspvku m bt nanejv zobrazeno? (Pednastaveno: 120)');
 @define('PLUGIN_SHOUTBOX_MAXENTRIES',           'Poet vkik');
 @define('PLUGIN_SHOUTBOX_MAXENTRIES_BLAHBLAH',  'Kolik poslednch vkik se m zobrazovat? (Pednastaveno: 15)');
-
-?>
+@define('GENERAL_PLUGIN_BOX_COLS',              'Sloupce shoutboxu');
+@define('GENERAL_PLUGIN_BOX_COLS_BLAHBLAH',     'Poet sloupc pole pro zadvn vkik');
+@define('GENERAL_PLUGIN_BOX_ROWS',              'Poet dek shoutboxu');
+@define('GENERAL_PLUGIN_BOX_ROWS_BLAHBLAH',     'Poet dek pole pro zadvn vkik');
\ No newline at end of file
