@@ -1,7 +1,7 @@
-<?php # $Id: lang_en.inc.php 1381 2006-08-15 10:14:56Z elf2000 $
+<?php # $Id: lang_en.inc.php 2517 2009-06-01 02:36:52Z brockhaus $
 
 /**
- *  @version $Revision: 1381 $
+ *  @version $Revision: 2517 $
  *  @author Translator Name <yourmail@example.com>
  *  EN-Revision: Revision of lang_en.inc.php
  */
@@ -17,4 +17,8 @@
 @define('PLUGIN_SHOUTBOX_MAXENTRIES', 'Maximum number of comments');
 @define('PLUGIN_SHOUTBOX_MAXENTRIES_BLAHBLAH', 'How many comments will be shown? (Default: 15)');
 
+@define('GENERAL_PLUGIN_BOX_COLS', 	'Shoutbox columns');
+@define('GENERAL_PLUGIN_BOX_COLS_BLAHBLAH', 	'Column count of the shoutbox input element.');
+@define('GENERAL_PLUGIN_BOX_ROWS', 	'Shoutbox rows');
+@define('GENERAL_PLUGIN_BOX_ROWS_BLAHBLAH', 	'Row count of thesShoutbox input element.');
 ?>
