@@ -1,4 +1,4 @@
-<?php # $Id: rss.php 2326 2008-08-27 19:20:23Z garvinhicking $
+<?php # $Id: rss.php 2446 2009-01-30 14:03:31Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -173,7 +173,12 @@ if (is_array($plugins)) {
                 !preg_match('@FeedBurn@i', $_SERVER['HTTP_USER_AGENT']) &&
                 !(serendipity_userLoggedIn() && isset($_GET['forceLocal']))
                ) {
-                $url = 'http://feeds.feedburner.com/' . $plugin->get_config('fb_id');
+                $fbid = $plugin->get_config('fb_id');
+                if (stristr($fbid, 'http://')) {
+                    $url = $fbid;
+                } else {
+                    $url = 'http://feeds.feedburner.com/' . $fbid;
+                }
                 header('Status: 302 Found');
                 header('Location: ' . $url);
                 exit;
