@@ -1,10 +1,10 @@
-<?php # $Id: lang_de.inc.php 7 2005-04-16 06:39:31Z s_bergmann $
+<?php # $Id: lang_de.inc.php 1731 2007-06-18 10:47:59Z garvinhicking $
 @define('REPLY', 'Antworten');
 @define('SAYS', 'schreibt');
 @define('LINK_TO_COMMENT', 'Link zu Kommentar #%d');
 @define('ENTRY_POSTED_BY', 'Dieser Eintrag wurde geschrieben von ');
 @define('FILED_UNDER', 'und ist abgelegt in');
-@define('LEAVE_RESPONSE', 'Sie knnen einen %sKommentar hinterlassen%s, oder ein %sTrackback%s von Ihrem eigenen Blog senden.');
+@define('LEAVE_RESPONSE', 'Sie k&ouml;nnen einen %sKommentar hinterlassen%s, oder ein %sTrackback%s von Ihrem eigenen Blog senden.');
 @define('SUBJECT_TO_MODERATION', 'Alle neuen Kommentare werden moderiert, bevor sie auf dieser Seite erscheinen.');
 @define('COMMENTS_CLOSED', 'Sowohl Kommentare als auch Trackbacks sind derzeit deaktiviert.');
 @define('PROUDLY_POWERED_BY', 'Dieses Weblog wird betrieben mit ');
