@@ -1,8 +1,8 @@
-<?php # $Id: wfwcomment.php 7 2005-04-16 06:39:31Z s_bergmann $
+<?php # $Id: wfwcomment.php 1055 2006-04-06 09:14:11Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
-include_once('serendipity_config.inc.php');
+include('serendipity_config.inc.php');
 
 if ($_REQUEST['cid'] != '' && $HTTP_RAW_POST_DATA != '') {
     $comment = array();
